# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.ads_api import AdsApi


class TestAdsApi(unittest.TestCase):
    """AdsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdsApi()

    def tearDown(self) -> None:
        pass

    def test_ad_options(self) -> None:
        """Test case for ad_options

        Ad Options
        """
        pass

    def test_ads_options(self) -> None:
        """Test case for ads_options

        Ads Options
        """
        pass

    def test_create_ad(self) -> None:
        """Test case for create_ad

        Create Ad
        """
        pass

    def test_delete_ad(self) -> None:
        """Test case for delete_ad

        Delete Ad
        """
        pass

    def test_list_ads(self) -> None:
        """Test case for list_ads

        List Ads
        """
        pass

    def test_show_ad(self) -> None:
        """Test case for show_ad

        Show Ad
        """
        pass

    def test_update_ad(self) -> None:
        """Test case for update_ad

        Update Ad
        """
        pass


if __name__ == '__main__':
    unittest.main()
