# coding: utf-8

# flake8: noqa
"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from smartytalent_client.models.ad_attributes_schema import AdAttributesSchema
from smartytalent_client.models.ad_attributes_schema_images_inner import AdAttributesSchemaImagesInner
from smartytalent_client.models.ad_relationships_job_data_schema import AdRelationshipsJobDataSchema
from smartytalent_client.models.ad_relationships_job_schema import AdRelationshipsJobSchema
from smartytalent_client.models.ad_relationships_schema import AdRelationshipsSchema
from smartytalent_client.models.ad_resource_schema import AdResourceSchema
from smartytalent_client.models.ad_schema import AdSchema
from smartytalent_client.models.ads_schema import AdsSchema
from smartytalent_client.models.apikey_attributes_schema import ApikeyAttributesSchema
from smartytalent_client.models.apikey_relationships_schema import ApikeyRelationshipsSchema
from smartytalent_client.models.apikey_relationships_user_data_schema import ApikeyRelationshipsUserDataSchema
from smartytalent_client.models.apikey_relationships_user_schema import ApikeyRelationshipsUserSchema
from smartytalent_client.models.apikey_resource_schema import ApikeyResourceSchema
from smartytalent_client.models.apikey_schema import ApikeySchema
from smartytalent_client.models.apikeys_schema import ApikeysSchema
from smartytalent_client.models.assessment_attributes_schema import AssessmentAttributesSchema
from smartytalent_client.models.assessment_relationships_candidate_data_schema import AssessmentRelationshipsCandidateDataSchema
from smartytalent_client.models.assessment_relationships_candidate_schema import AssessmentRelationshipsCandidateSchema
from smartytalent_client.models.assessment_relationships_job_data_schema import AssessmentRelationshipsJobDataSchema
from smartytalent_client.models.assessment_relationships_job_schema import AssessmentRelationshipsJobSchema
from smartytalent_client.models.assessment_relationships_schema import AssessmentRelationshipsSchema
from smartytalent_client.models.assessment_resource_schema import AssessmentResourceSchema
from smartytalent_client.models.assessment_schema import AssessmentSchema
from smartytalent_client.models.assessments_schema import AssessmentsSchema
from smartytalent_client.models.browser_attributes_schema import BrowserAttributesSchema
from smartytalent_client.models.browser_relationships_schema import BrowserRelationshipsSchema
from smartytalent_client.models.browser_relationships_translations_data_schema import BrowserRelationshipsTranslationsDataSchema
from smartytalent_client.models.browser_relationships_translations_schema import BrowserRelationshipsTranslationsSchema
from smartytalent_client.models.browser_resource_schema import BrowserResourceSchema
from smartytalent_client.models.browser_schema import BrowserSchema
from smartytalent_client.models.browsers_schema import BrowsersSchema
from smartytalent_client.models.call_attributes_schema import CallAttributesSchema
from smartytalent_client.models.call_relationships_schema import CallRelationshipsSchema
from smartytalent_client.models.call_relationships_translations_data_schema import CallRelationshipsTranslationsDataSchema
from smartytalent_client.models.call_relationships_translations_schema import CallRelationshipsTranslationsSchema
from smartytalent_client.models.call_resource_schema import CallResourceSchema
from smartytalent_client.models.call_schema import CallSchema
from smartytalent_client.models.calls_schema import CallsSchema
from smartytalent_client.models.candidate_attributes_schema import CandidateAttributesSchema
from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema
from smartytalent_client.models.candidate_relationships_job_data_schema import CandidateRelationshipsJobDataSchema
from smartytalent_client.models.candidate_relationships_job_schema import CandidateRelationshipsJobSchema
from smartytalent_client.models.candidate_relationships_operations_data_schema import CandidateRelationshipsOperationsDataSchema
from smartytalent_client.models.candidate_relationships_operations_schema import CandidateRelationshipsOperationsSchema
from smartytalent_client.models.candidate_relationships_schema import CandidateRelationshipsSchema
from smartytalent_client.models.candidate_relationships_talent_data_schema import CandidateRelationshipsTalentDataSchema
from smartytalent_client.models.candidate_relationships_talent_schema import CandidateRelationshipsTalentSchema
from smartytalent_client.models.candidate_relationships_translations_data_schema import CandidateRelationshipsTranslationsDataSchema
from smartytalent_client.models.candidate_relationships_translations_schema import CandidateRelationshipsTranslationsSchema
from smartytalent_client.models.candidate_resource_schema import CandidateResourceSchema
from smartytalent_client.models.candidate_schema import CandidateSchema
from smartytalent_client.models.candidates_schema import CandidatesSchema
from smartytalent_client.models.chat_attributes_schema import ChatAttributesSchema
from smartytalent_client.models.chat_relationships_schema import ChatRelationshipsSchema
from smartytalent_client.models.chat_relationships_translations_data_schema import ChatRelationshipsTranslationsDataSchema
from smartytalent_client.models.chat_relationships_translations_schema import ChatRelationshipsTranslationsSchema
from smartytalent_client.models.chat_resource_schema import ChatResourceSchema
from smartytalent_client.models.chat_schema import ChatSchema
from smartytalent_client.models.chats_schema import ChatsSchema
from smartytalent_client.models.conversation_attributes_schema import ConversationAttributesSchema
from smartytalent_client.models.conversation_relationships_candidate_data_schema import ConversationRelationshipsCandidateDataSchema
from smartytalent_client.models.conversation_relationships_candidate_schema import ConversationRelationshipsCandidateSchema
from smartytalent_client.models.conversation_relationships_schema import ConversationRelationshipsSchema
from smartytalent_client.models.conversation_resource_schema import ConversationResourceSchema
from smartytalent_client.models.conversation_schema import ConversationSchema
from smartytalent_client.models.conversations_schema import ConversationsSchema
from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody
from smartytalent_client.models.create_ad_request_body_data import CreateAdRequestBodyData
from smartytalent_client.models.create_apikey_request_body import CreateApikeyRequestBody
from smartytalent_client.models.create_apikey_request_body_data import CreateApikeyRequestBodyData
from smartytalent_client.models.create_assessment_request_body import CreateAssessmentRequestBody
from smartytalent_client.models.create_assessment_request_body_data import CreateAssessmentRequestBodyData
from smartytalent_client.models.create_browser_request_body import CreateBrowserRequestBody
from smartytalent_client.models.create_browser_request_body_data import CreateBrowserRequestBodyData
from smartytalent_client.models.create_call_request_body import CreateCallRequestBody
from smartytalent_client.models.create_call_request_body_data import CreateCallRequestBodyData
from smartytalent_client.models.create_candidate_request_body import CreateCandidateRequestBody
from smartytalent_client.models.create_candidate_request_body_data import CreateCandidateRequestBodyData
from smartytalent_client.models.create_chat_request_body import CreateChatRequestBody
from smartytalent_client.models.create_chat_request_body_data import CreateChatRequestBodyData
from smartytalent_client.models.create_conversation_request_body import CreateConversationRequestBody
from smartytalent_client.models.create_conversation_request_body_data import CreateConversationRequestBodyData
from smartytalent_client.models.create_email_request_body import CreateEmailRequestBody
from smartytalent_client.models.create_email_request_body_data import CreateEmailRequestBodyData
from smartytalent_client.models.create_file_request_body import CreateFileRequestBody
from smartytalent_client.models.create_file_request_body_data import CreateFileRequestBodyData
from smartytalent_client.models.create_finder_request_body import CreateFinderRequestBody
from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData
from smartytalent_client.models.create_form_request_body import CreateFormRequestBody
from smartytalent_client.models.create_form_request_body_data import CreateFormRequestBodyData
from smartytalent_client.models.create_job_request_body import CreateJobRequestBody
from smartytalent_client.models.create_job_request_body_data import CreateJobRequestBodyData
from smartytalent_client.models.create_link_request_body import CreateLinkRequestBody
from smartytalent_client.models.create_link_request_body_data import CreateLinkRequestBodyData
from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody
from smartytalent_client.models.create_meeting_ai_session_request_body_data import CreateMeetingAiSessionRequestBodyData
from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody
from smartytalent_client.models.create_meeting_attendee_request_body_data import CreateMeetingAttendeeRequestBodyData
from smartytalent_client.models.create_meeting_request_body import CreateMeetingRequestBody
from smartytalent_client.models.create_meeting_request_body_data import CreateMeetingRequestBodyData
from smartytalent_client.models.create_note_request_body import CreateNoteRequestBody
from smartytalent_client.models.create_note_request_body_data import CreateNoteRequestBodyData
from smartytalent_client.models.create_notification_request_body import CreateNotificationRequestBody
from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData
from smartytalent_client.models.create_operation_request_body import CreateOperationRequestBody
from smartytalent_client.models.create_operation_request_body_data import CreateOperationRequestBodyData
from smartytalent_client.models.create_persona_request_body import CreatePersonaRequestBody
from smartytalent_client.models.create_persona_request_body_data import CreatePersonaRequestBodyData
from smartytalent_client.models.create_report_request_body import CreateReportRequestBody
from smartytalent_client.models.create_report_request_body_data import CreateReportRequestBodyData
from smartytalent_client.models.create_role_request_body import CreateRoleRequestBody
from smartytalent_client.models.create_role_request_body_data import CreateRoleRequestBodyData
from smartytalent_client.models.create_talent_request_body import CreateTalentRequestBody
from smartytalent_client.models.create_talent_request_body_data import CreateTalentRequestBodyData
from smartytalent_client.models.create_tenant_request_body import CreateTenantRequestBody
from smartytalent_client.models.create_tenant_request_body_data import CreateTenantRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body import CreateTenantUploadRequestBody
from smartytalent_client.models.create_tenant_upload_request_body_data import CreateTenantUploadRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body_data_attributes import CreateTenantUploadRequestBodyDataAttributes
from smartytalent_client.models.create_translation_request_body import CreateTranslationRequestBody
from smartytalent_client.models.create_translation_request_body_data import CreateTranslationRequestBodyData
from smartytalent_client.models.create_user_request_body import CreateUserRequestBody
from smartytalent_client.models.create_user_request_body_data import CreateUserRequestBodyData
from smartytalent_client.models.create_user_upload_request_body import CreateUserUploadRequestBody
from smartytalent_client.models.create_user_upload_request_body_data import CreateUserUploadRequestBodyData
from smartytalent_client.models.create_user_upload_request_body_data_attributes import CreateUserUploadRequestBodyDataAttributes
from smartytalent_client.models.create_webhook_request_body import CreateWebhookRequestBody
from smartytalent_client.models.create_webhook_request_body_data import CreateWebhookRequestBodyData
from smartytalent_client.models.email_attributes_schema import EmailAttributesSchema
from smartytalent_client.models.email_relationships_candidate_data_schema import EmailRelationshipsCandidateDataSchema
from smartytalent_client.models.email_relationships_candidate_schema import EmailRelationshipsCandidateSchema
from smartytalent_client.models.email_relationships_operation_data_schema import EmailRelationshipsOperationDataSchema
from smartytalent_client.models.email_relationships_operation_schema import EmailRelationshipsOperationSchema
from smartytalent_client.models.email_relationships_report_data_schema import EmailRelationshipsReportDataSchema
from smartytalent_client.models.email_relationships_report_schema import EmailRelationshipsReportSchema
from smartytalent_client.models.email_relationships_schema import EmailRelationshipsSchema
from smartytalent_client.models.email_relationships_translations_data_schema import EmailRelationshipsTranslationsDataSchema
from smartytalent_client.models.email_relationships_translations_schema import EmailRelationshipsTranslationsSchema
from smartytalent_client.models.email_resource_schema import EmailResourceSchema
from smartytalent_client.models.email_schema import EmailSchema
from smartytalent_client.models.emails_schema import EmailsSchema
from smartytalent_client.models.error_object_schema import ErrorObjectSchema
from smartytalent_client.models.error_schema import ErrorSchema
from smartytalent_client.models.file_attributes_schema import FileAttributesSchema
from smartytalent_client.models.file_relationships_link_data_schema import FileRelationshipsLinkDataSchema
from smartytalent_client.models.file_relationships_link_schema import FileRelationshipsLinkSchema
from smartytalent_client.models.file_relationships_schema import FileRelationshipsSchema
from smartytalent_client.models.file_resource_schema import FileResourceSchema
from smartytalent_client.models.file_schema import FileSchema
from smartytalent_client.models.files_schema import FilesSchema
from smartytalent_client.models.finder_attributes_schema import FinderAttributesSchema
from smartytalent_client.models.finder_relationships_candidates_data_schema import FinderRelationshipsCandidatesDataSchema
from smartytalent_client.models.finder_relationships_candidates_schema import FinderRelationshipsCandidatesSchema
from smartytalent_client.models.finder_relationships_jobs_data_schema import FinderRelationshipsJobsDataSchema
from smartytalent_client.models.finder_relationships_jobs_schema import FinderRelationshipsJobsSchema
from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema
from smartytalent_client.models.finder_relationships_talents_data_schema import FinderRelationshipsTalentsDataSchema
from smartytalent_client.models.finder_relationships_talents_schema import FinderRelationshipsTalentsSchema
from smartytalent_client.models.finder_relationships_users_data_schema import FinderRelationshipsUsersDataSchema
from smartytalent_client.models.finder_relationships_users_schema import FinderRelationshipsUsersSchema
from smartytalent_client.models.finder_resource_schema import FinderResourceSchema
from smartytalent_client.models.finder_schema import FinderSchema
from smartytalent_client.models.finders_schema import FindersSchema
from smartytalent_client.models.form_attributes_schema import FormAttributesSchema
from smartytalent_client.models.form_relationships_schema import FormRelationshipsSchema
from smartytalent_client.models.form_relationships_translations_data_schema import FormRelationshipsTranslationsDataSchema
from smartytalent_client.models.form_relationships_translations_schema import FormRelationshipsTranslationsSchema
from smartytalent_client.models.form_resource_schema import FormResourceSchema
from smartytalent_client.models.form_schema import FormSchema
from smartytalent_client.models.forms_schema import FormsSchema
from smartytalent_client.models.job_attributes_location_item_schema import JobAttributesLocationItemSchema
from smartytalent_client.models.job_attributes_organization_address_schema import JobAttributesOrganizationAddressSchema
from smartytalent_client.models.job_attributes_organization_schema import JobAttributesOrganizationSchema
from smartytalent_client.models.job_attributes_schema import JobAttributesSchema
from smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema import JobAttributesSettingsConversationCandidateInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema import JobAttributesSettingsConversationEmailContactSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema import JobAttributesSettingsConversationEmailDelaysSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_schema import JobAttributesSettingsConversationEmailSchema
from smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema import JobAttributesSettingsConversationPersonaInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema
from smartytalent_client.models.job_attributes_settings_criterias_schema import JobAttributesSettingsCriteriasSchema
from smartytalent_client.models.job_attributes_settings_operation_schema import JobAttributesSettingsOperationSchema
from smartytalent_client.models.job_attributes_settings_persona_schema import JobAttributesSettingsPersonaSchema
from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema
from smartytalent_client.models.job_attributes_site_item_schema import JobAttributesSiteItemSchema
from smartytalent_client.models.job_criteria_schema import JobCriteriaSchema
from smartytalent_client.models.job_relationships_candidates_data_schema import JobRelationshipsCandidatesDataSchema
from smartytalent_client.models.job_relationships_candidates_schema import JobRelationshipsCandidatesSchema
from smartytalent_client.models.job_relationships_conversations_data_schema import JobRelationshipsConversationsDataSchema
from smartytalent_client.models.job_relationships_conversations_schema import JobRelationshipsConversationsSchema
from smartytalent_client.models.job_relationships_operations_data_schema import JobRelationshipsOperationsDataSchema
from smartytalent_client.models.job_relationships_operations_schema import JobRelationshipsOperationsSchema
from smartytalent_client.models.job_relationships_personas_data_schema import JobRelationshipsPersonasDataSchema
from smartytalent_client.models.job_relationships_personas_schema import JobRelationshipsPersonasSchema
from smartytalent_client.models.job_relationships_schema import JobRelationshipsSchema
from smartytalent_client.models.job_relationships_translations_data_schema import JobRelationshipsTranslationsDataSchema
from smartytalent_client.models.job_relationships_translations_schema import JobRelationshipsTranslationsSchema
from smartytalent_client.models.job_resource_schema import JobResourceSchema
from smartytalent_client.models.job_schema import JobSchema
from smartytalent_client.models.jobs_schema import JobsSchema
from smartytalent_client.models.link_attributes_schema import LinkAttributesSchema
from smartytalent_client.models.link_relationships_file_data_schema import LinkRelationshipsFileDataSchema
from smartytalent_client.models.link_relationships_file_schema import LinkRelationshipsFileSchema
from smartytalent_client.models.link_relationships_schema import LinkRelationshipsSchema
from smartytalent_client.models.link_resource_schema import LinkResourceSchema
from smartytalent_client.models.link_schema import LinkSchema
from smartytalent_client.models.links_schema import LinksSchema
from smartytalent_client.models.list_candidate_jobs_relationship import ListCandidateJobsRelationship
from smartytalent_client.models.list_candidate_talents_relationship import ListCandidateTalentsRelationship
from smartytalent_client.models.list_job_candidates_relationship import ListJobCandidatesRelationship
from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship
from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship
from smartytalent_client.models.list_user_apikeys_relationship import ListUserApikeysRelationship
from smartytalent_client.models.list_user_jobs_relationship import ListUserJobsRelationship
from smartytalent_client.models.list_user_roles_relationship import ListUserRolesRelationship
from smartytalent_client.models.meeting_ai_session_attributes_schema import MeetingAiSessionAttributesSchema
from smartytalent_client.models.meeting_ai_session_attributes_schema_realtime_session import MeetingAiSessionAttributesSchemaRealtimeSession
from smartytalent_client.models.meeting_ai_session_resource_schema import MeetingAiSessionResourceSchema
from smartytalent_client.models.meeting_ai_session_schema import MeetingAiSessionSchema
from smartytalent_client.models.meeting_ai_session_settings_schema import MeetingAiSessionSettingsSchema
from smartytalent_client.models.meeting_attendee_attributes_schema import MeetingAttendeeAttributesSchema
from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships import MeetingAttendeeResourceSchemaAllOfRelationships
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting import MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data import MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData
from smartytalent_client.models.meeting_attendee_response_attributes_schema import MeetingAttendeeResponseAttributesSchema
from smartytalent_client.models.meeting_attendee_schema import MeetingAttendeeSchema
from smartytalent_client.models.meeting_attributes_schema import MeetingAttributesSchema
from smartytalent_client.models.meeting_lobby_attributes_schema import MeetingLobbyAttributesSchema
from smartytalent_client.models.meeting_lobby_resource_schema import MeetingLobbyResourceSchema
from smartytalent_client.models.meeting_lobby_schema import MeetingLobbySchema
from smartytalent_client.models.meeting_relationships_participants_data_schema import MeetingRelationshipsParticipantsDataSchema
from smartytalent_client.models.meeting_relationships_participants_schema import MeetingRelationshipsParticipantsSchema
from smartytalent_client.models.meeting_relationships_schema import MeetingRelationshipsSchema
from smartytalent_client.models.meeting_resource_schema import MeetingResourceSchema
from smartytalent_client.models.meeting_schema import MeetingSchema
from smartytalent_client.models.meeting_transcription_attributes_schema import MeetingTranscriptionAttributesSchema
from smartytalent_client.models.meeting_transcription_request_body import MeetingTranscriptionRequestBody
from smartytalent_client.models.meeting_transcription_request_body_data import MeetingTranscriptionRequestBodyData
from smartytalent_client.models.meeting_transcription_schema import MeetingTranscriptionSchema
from smartytalent_client.models.meeting_transcription_schema_data import MeetingTranscriptionSchemaData
from smartytalent_client.models.meeting_transcription_settings_schema import MeetingTranscriptionSettingsSchema
from smartytalent_client.models.meetings_schema import MeetingsSchema
from smartytalent_client.models.note_attributes_schema import NoteAttributesSchema
from smartytalent_client.models.note_relationships_candidate_data_schema import NoteRelationshipsCandidateDataSchema
from smartytalent_client.models.note_relationships_candidate_schema import NoteRelationshipsCandidateSchema
from smartytalent_client.models.note_relationships_operation_data_schema import NoteRelationshipsOperationDataSchema
from smartytalent_client.models.note_relationships_operation_schema import NoteRelationshipsOperationSchema
from smartytalent_client.models.note_relationships_report_data_schema import NoteRelationshipsReportDataSchema
from smartytalent_client.models.note_relationships_report_schema import NoteRelationshipsReportSchema
from smartytalent_client.models.note_relationships_schema import NoteRelationshipsSchema
from smartytalent_client.models.note_relationships_translations_data_schema import NoteRelationshipsTranslationsDataSchema
from smartytalent_client.models.note_relationships_translations_schema import NoteRelationshipsTranslationsSchema
from smartytalent_client.models.note_resource_schema import NoteResourceSchema
from smartytalent_client.models.note_schema import NoteSchema
from smartytalent_client.models.notes_schema import NotesSchema
from smartytalent_client.models.notification_attributes_schema import NotificationAttributesSchema
from smartytalent_client.models.notification_relationships_schema import NotificationRelationshipsSchema
from smartytalent_client.models.notification_relationships_schema_users import NotificationRelationshipsSchemaUsers
from smartytalent_client.models.notification_relationships_schema_users_data_inner import NotificationRelationshipsSchemaUsersDataInner
from smartytalent_client.models.notification_resource_schema import NotificationResourceSchema
from smartytalent_client.models.notification_schema import NotificationSchema
from smartytalent_client.models.notifications_schema import NotificationsSchema
from smartytalent_client.models.operation_attributes_schema import OperationAttributesSchema
from smartytalent_client.models.operation_relationships_candidate_data_schema import OperationRelationshipsCandidateDataSchema
from smartytalent_client.models.operation_relationships_candidate_schema import OperationRelationshipsCandidateSchema
from smartytalent_client.models.operation_relationships_job_data_schema import OperationRelationshipsJobDataSchema
from smartytalent_client.models.operation_relationships_job_schema import OperationRelationshipsJobSchema
from smartytalent_client.models.operation_relationships_schema import OperationRelationshipsSchema
from smartytalent_client.models.operation_resource_schema import OperationResourceSchema
from smartytalent_client.models.operation_schema import OperationSchema
from smartytalent_client.models.operations_schema import OperationsSchema
from smartytalent_client.models.persona_attributes_schema import PersonaAttributesSchema
from smartytalent_client.models.persona_relationships_candidates_data_schema import PersonaRelationshipsCandidatesDataSchema
from smartytalent_client.models.persona_relationships_candidates_schema import PersonaRelationshipsCandidatesSchema
from smartytalent_client.models.persona_relationships_operations_data_schema import PersonaRelationshipsOperationsDataSchema
from smartytalent_client.models.persona_relationships_operations_schema import PersonaRelationshipsOperationsSchema
from smartytalent_client.models.persona_relationships_schema import PersonaRelationshipsSchema
from smartytalent_client.models.persona_relationships_talents_data_schema import PersonaRelationshipsTalentsDataSchema
from smartytalent_client.models.persona_relationships_talents_schema import PersonaRelationshipsTalentsSchema
from smartytalent_client.models.persona_relationships_translations_data_schema import PersonaRelationshipsTranslationsDataSchema
from smartytalent_client.models.persona_relationships_translations_schema import PersonaRelationshipsTranslationsSchema
from smartytalent_client.models.persona_resource_schema import PersonaResourceSchema
from smartytalent_client.models.persona_schema import PersonaSchema
from smartytalent_client.models.personas_schema import PersonasSchema
from smartytalent_client.models.purchase_tenant_phone_number_request import PurchaseTenantPhoneNumberRequest
from smartytalent_client.models.purchase_tenant_phone_number_request_data import PurchaseTenantPhoneNumberRequestData
from smartytalent_client.models.purchase_tenant_phone_number_request_data_attributes import PurchaseTenantPhoneNumberRequestDataAttributes
from smartytalent_client.models.report_attributes_schema import ReportAttributesSchema
from smartytalent_client.models.report_relationships_schema import ReportRelationshipsSchema
from smartytalent_client.models.report_relationships_tenants_data_schema import ReportRelationshipsTenantsDataSchema
from smartytalent_client.models.report_relationships_tenants_schema import ReportRelationshipsTenantsSchema
from smartytalent_client.models.report_resource_schema import ReportResourceSchema
from smartytalent_client.models.report_schema import ReportSchema
from smartytalent_client.models.reports_schema import ReportsSchema
from smartytalent_client.models.resource_identifier_schema import ResourceIdentifierSchema
from smartytalent_client.models.resource_links_schema import ResourceLinksSchema
from smartytalent_client.models.resource_relationships_links_schema import ResourceRelationshipsLinksSchema
from smartytalent_client.models.resource_relationships_meta_schema import ResourceRelationshipsMetaSchema
from smartytalent_client.models.resource_schema import ResourceSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.resources_links_schema import ResourcesLinksSchema
from smartytalent_client.models.resources_meta_page_schema import ResourcesMetaPageSchema
from smartytalent_client.models.resources_meta_schema import ResourcesMetaSchema
from smartytalent_client.models.role_attributes_schema import RoleAttributesSchema
from smartytalent_client.models.role_relationships_permissions_data_schema import RoleRelationshipsPermissionsDataSchema
from smartytalent_client.models.role_relationships_permissions_schema import RoleRelationshipsPermissionsSchema
from smartytalent_client.models.role_relationships_schema import RoleRelationshipsSchema
from smartytalent_client.models.role_relationships_users_data_schema import RoleRelationshipsUsersDataSchema
from smartytalent_client.models.role_relationships_users_schema import RoleRelationshipsUsersSchema
from smartytalent_client.models.role_resource_schema import RoleResourceSchema
from smartytalent_client.models.role_schema import RoleSchema
from smartytalent_client.models.roles_schema import RolesSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema
from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema
from smartytalent_client.models.talent_attributes_desired_employment_type_schema import TalentAttributesDesiredEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_desired_role_schema import TalentAttributesDesiredRoleSchema
from smartytalent_client.models.talent_attributes_employment_type_schema import TalentAttributesEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema
from smartytalent_client.models.talent_attributes_social_link_schema import TalentAttributesSocialLinkSchema
from smartytalent_client.models.talent_availability_received_criteria_schema import TalentAvailabilityReceivedCriteriaSchema
from smartytalent_client.models.talent_received_criteria_schema import TalentReceivedCriteriaSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema
from smartytalent_client.models.talent_referral_schema_referrer import TalentReferralSchemaReferrer
from smartytalent_client.models.talent_relationships_candidates_data_schema import TalentRelationshipsCandidatesDataSchema
from smartytalent_client.models.talent_relationships_candidates_schema import TalentRelationshipsCandidatesSchema
from smartytalent_client.models.talent_relationships_files_data_schema import TalentRelationshipsFilesDataSchema
from smartytalent_client.models.talent_relationships_files_schema import TalentRelationshipsFilesSchema
from smartytalent_client.models.talent_relationships_operations_data_schema import TalentRelationshipsOperationsDataSchema
from smartytalent_client.models.talent_relationships_operations_schema import TalentRelationshipsOperationsSchema
from smartytalent_client.models.talent_relationships_schema import TalentRelationshipsSchema
from smartytalent_client.models.talent_relationships_translations_data_schema import TalentRelationshipsTranslationsDataSchema
from smartytalent_client.models.talent_relationships_translations_schema import TalentRelationshipsTranslationsSchema
from smartytalent_client.models.talent_resource_schema import TalentResourceSchema
from smartytalent_client.models.talent_schema import TalentSchema
from smartytalent_client.models.talents_schema import TalentsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_schema import TenantAttributesSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema
from smartytalent_client.models.tenant_attributes_settings_schema_calling import TenantAttributesSettingsSchemaCalling
from smartytalent_client.models.tenant_resource_schema import TenantResourceSchema
from smartytalent_client.models.tenant_schema import TenantSchema
from smartytalent_client.models.tenant_upload_attributes_schema import TenantUploadAttributesSchema
from smartytalent_client.models.tenant_upload_resource_schema import TenantUploadResourceSchema
from smartytalent_client.models.tenant_upload_schema import TenantUploadSchema
from smartytalent_client.models.tenants_meta_page_schema import TenantsMetaPageSchema
from smartytalent_client.models.tenants_meta_schema import TenantsMetaSchema
from smartytalent_client.models.tenants_schema import TenantsSchema
from smartytalent_client.models.timeline_attributes_schema import TimelineAttributesSchema
from smartytalent_client.models.timeline_attributes_schema_changes_value import TimelineAttributesSchemaChangesValue
from smartytalent_client.models.timeline_attributes_schema_summary_value import TimelineAttributesSchemaSummaryValue
from smartytalent_client.models.timeline_attributes_schema_summary_value_user import TimelineAttributesSchemaSummaryValueUser
from smartytalent_client.models.timeline_attributes_schema_timestamps import TimelineAttributesSchemaTimestamps
from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema
from smartytalent_client.models.timeline_schema import TimelineSchema
from smartytalent_client.models.timelines_schema import TimelinesSchema
from smartytalent_client.models.translation_attributes_schema import TranslationAttributesSchema
from smartytalent_client.models.translation_relationships_candidate_data_schema import TranslationRelationshipsCandidateDataSchema
from smartytalent_client.models.translation_relationships_candidate_schema import TranslationRelationshipsCandidateSchema
from smartytalent_client.models.translation_relationships_job_data_schema import TranslationRelationshipsJobDataSchema
from smartytalent_client.models.translation_relationships_job_schema import TranslationRelationshipsJobSchema
from smartytalent_client.models.translation_relationships_report_data_schema import TranslationRelationshipsReportDataSchema
from smartytalent_client.models.translation_relationships_report_schema import TranslationRelationshipsReportSchema
from smartytalent_client.models.translation_relationships_schema import TranslationRelationshipsSchema
from smartytalent_client.models.translation_relationships_talent_data_schema import TranslationRelationshipsTalentDataSchema
from smartytalent_client.models.translation_relationships_talent_schema import TranslationRelationshipsTalentSchema
from smartytalent_client.models.translation_resource_schema import TranslationResourceSchema
from smartytalent_client.models.translation_schema import TranslationSchema
from smartytalent_client.models.translations_schema import TranslationsSchema
from smartytalent_client.models.update_ad_request_body import UpdateAdRequestBody
from smartytalent_client.models.update_ad_request_body_data import UpdateAdRequestBodyData
from smartytalent_client.models.update_apikey_request_body import UpdateApikeyRequestBody
from smartytalent_client.models.update_apikey_request_body_data import UpdateApikeyRequestBodyData
from smartytalent_client.models.update_assessment_request_body import UpdateAssessmentRequestBody
from smartytalent_client.models.update_assessment_request_body_data import UpdateAssessmentRequestBodyData
from smartytalent_client.models.update_browser_request_body import UpdateBrowserRequestBody
from smartytalent_client.models.update_browser_request_body_data import UpdateBrowserRequestBodyData
from smartytalent_client.models.update_call_request_body import UpdateCallRequestBody
from smartytalent_client.models.update_call_request_body_data import UpdateCallRequestBodyData
from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody
from smartytalent_client.models.update_candidate_request_body_data import UpdateCandidateRequestBodyData
from smartytalent_client.models.update_chat_request_body import UpdateChatRequestBody
from smartytalent_client.models.update_chat_request_body_data import UpdateChatRequestBodyData
from smartytalent_client.models.update_conversation_request_body import UpdateConversationRequestBody
from smartytalent_client.models.update_conversation_request_body_data import UpdateConversationRequestBodyData
from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody
from smartytalent_client.models.update_email_request_body_data import UpdateEmailRequestBodyData
from smartytalent_client.models.update_file_request_body import UpdateFileRequestBody
from smartytalent_client.models.update_file_request_body_data import UpdateFileRequestBodyData
from smartytalent_client.models.update_finder_request_body import UpdateFinderRequestBody
from smartytalent_client.models.update_finder_request_body_data import UpdateFinderRequestBodyData
from smartytalent_client.models.update_form_request_body import UpdateFormRequestBody
from smartytalent_client.models.update_form_request_body_data import UpdateFormRequestBodyData
from smartytalent_client.models.update_job_request_body import UpdateJobRequestBody
from smartytalent_client.models.update_job_request_body_data import UpdateJobRequestBodyData
from smartytalent_client.models.update_link_request_body import UpdateLinkRequestBody
from smartytalent_client.models.update_link_request_body_data import UpdateLinkRequestBodyData
from smartytalent_client.models.update_meeting_request_body import UpdateMeetingRequestBody
from smartytalent_client.models.update_meeting_request_body_data import UpdateMeetingRequestBodyData
from smartytalent_client.models.update_note_request_body import UpdateNoteRequestBody
from smartytalent_client.models.update_note_request_body_data import UpdateNoteRequestBodyData
from smartytalent_client.models.update_notification_request_body import UpdateNotificationRequestBody
from smartytalent_client.models.update_notification_request_body_data import UpdateNotificationRequestBodyData
from smartytalent_client.models.update_notification_request_body_data_attributes import UpdateNotificationRequestBodyDataAttributes
from smartytalent_client.models.update_operation_request_body import UpdateOperationRequestBody
from smartytalent_client.models.update_operation_request_body_data import UpdateOperationRequestBodyData
from smartytalent_client.models.update_persona_request_body import UpdatePersonaRequestBody
from smartytalent_client.models.update_persona_request_body_data import UpdatePersonaRequestBodyData
from smartytalent_client.models.update_report_request_body import UpdateReportRequestBody
from smartytalent_client.models.update_report_request_body_data import UpdateReportRequestBodyData
from smartytalent_client.models.update_role_request_body import UpdateRoleRequestBody
from smartytalent_client.models.update_role_request_body_data import UpdateRoleRequestBodyData
from smartytalent_client.models.update_talent_request_body import UpdateTalentRequestBody
from smartytalent_client.models.update_talent_request_body_data import UpdateTalentRequestBodyData
from smartytalent_client.models.update_tenant_request_body import UpdateTenantRequestBody
from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData
from smartytalent_client.models.update_translation_request_body import UpdateTranslationRequestBody
from smartytalent_client.models.update_translation_request_body_data import UpdateTranslationRequestBodyData
from smartytalent_client.models.update_user_request_body import UpdateUserRequestBody
from smartytalent_client.models.update_user_request_body_data import UpdateUserRequestBodyData
from smartytalent_client.models.update_webhook_request_body import UpdateWebhookRequestBody
from smartytalent_client.models.update_webhook_request_body_data import UpdateWebhookRequestBodyData
from smartytalent_client.models.user_attributes_schema import UserAttributesSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback
from smartytalent_client.models.user_relationships_apikeys_data_schema import UserRelationshipsApikeysDataSchema
from smartytalent_client.models.user_relationships_apikeys_schema import UserRelationshipsApikeysSchema
from smartytalent_client.models.user_relationships_jobs_data_schema import UserRelationshipsJobsDataSchema
from smartytalent_client.models.user_relationships_jobs_schema import UserRelationshipsJobsSchema
from smartytalent_client.models.user_relationships_role_data_schema import UserRelationshipsRoleDataSchema
from smartytalent_client.models.user_relationships_role_schema import UserRelationshipsRoleSchema
from smartytalent_client.models.user_relationships_schema import UserRelationshipsSchema
from smartytalent_client.models.user_resource_schema import UserResourceSchema
from smartytalent_client.models.user_schema import UserSchema
from smartytalent_client.models.user_upload_attributes_schema import UserUploadAttributesSchema
from smartytalent_client.models.user_upload_resource_schema import UserUploadResourceSchema
from smartytalent_client.models.user_upload_schema import UserUploadSchema
from smartytalent_client.models.users_schema import UsersSchema
from smartytalent_client.models.webhook_attributes_schema import WebhookAttributesSchema
from smartytalent_client.models.webhook_resource_schema import WebhookResourceSchema
from smartytalent_client.models.webhook_schema import WebhookSchema
from smartytalent_client.models.webhooks_schema import WebhooksSchema

