# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.user_upload_schema import UserUploadSchema

class TestUserUploadSchema(unittest.TestCase):
    """UserUploadSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserUploadSchema:
        """Test UserUploadSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserUploadSchema`
        """
        model = UserUploadSchema()
        if include_optional:
            return UserUploadSchema(
                data = smartytalent_client.models.user_upload_resource_schema.UserUploadResourceSchema(
                    type = 'user-uploads', 
                    id = '', 
                    attributes = smartytalent_client.models.user_upload_attributes_schema.UserUploadAttributesSchema(
                        upload_url = '', 
                        s3_key = '', 
                        url = '', 
                        content_type = '', 
                        purpose = 'avatar', 
                        expires_in = 56, 
                        max_file_size = 56, ), )
            )
        else:
            return UserUploadSchema(
        )
        """

    def testUserUploadSchema(self):
        """Test UserUploadSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
