# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema

class TestTenantAttributesSettingsSchema(unittest.TestCase):
    """TenantAttributesSettingsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TenantAttributesSettingsSchema:
        """Test TenantAttributesSettingsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TenantAttributesSettingsSchema`
        """
        model = TenantAttributesSettingsSchema()
        if include_optional:
            return TenantAttributesSettingsSchema(
                ad = smartytalent_client.models.ad.ad(),
                conversation = smartytalent_client.models.conversation.conversation(),
                report = smartytalent_client.models.report.report(),
                email = smartytalent_client.models.email.email(),
                language = '',
                calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                    enabled = True, 
                    twilio_subaccount_sid = '', 
                    twilio_phone_number = '', 
                    twilio_phone_sid = '', 
                    provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return TenantAttributesSettingsSchema(
        )
        """

    def testTenantAttributesSettingsSchema(self):
        """Test TenantAttributesSettingsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
