# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.calls_api import CallsApi


class TestCallsApi(unittest.TestCase):
    """CallsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CallsApi()

    def tearDown(self) -> None:
        pass

    def test_call_options(self) -> None:
        """Test case for call_options

        Call Options
        """
        pass

    def test_calls_options(self) -> None:
        """Test case for calls_options

        Calls Options
        """
        pass

    def test_create_call(self) -> None:
        """Test case for create_call

        Create Call
        """
        pass

    def test_delete_call(self) -> None:
        """Test case for delete_call

        Delete Call
        """
        pass

    def test_list_calls(self) -> None:
        """Test case for list_calls

        List Calls
        """
        pass

    def test_show_call(self) -> None:
        """Test case for show_call

        Show Call
        """
        pass

    def test_update_call(self) -> None:
        """Test case for update_call

        Update Call
        """
        pass


if __name__ == '__main__':
    unittest.main()
