# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.browsers_api import BrowsersApi


class TestBrowsersApi(unittest.TestCase):
    """BrowsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BrowsersApi()

    def tearDown(self) -> None:
        pass

    def test_browser_options(self) -> None:
        """Test case for browser_options

        Browser Options
        """
        pass

    def test_browsers_options(self) -> None:
        """Test case for browsers_options

        Browsers Options
        """
        pass

    def test_create_browser(self) -> None:
        """Test case for create_browser

        Create Browser
        """
        pass

    def test_delete_browser(self) -> None:
        """Test case for delete_browser

        Delete Browser
        """
        pass

    def test_list_browsers(self) -> None:
        """Test case for list_browsers

        List Browsers
        """
        pass

    def test_show_browser(self) -> None:
        """Test case for show_browser

        Show Browser
        """
        pass

    def test_update_browser(self) -> None:
        """Test case for update_browser

        Update Browser
        """
        pass


if __name__ == '__main__':
    unittest.main()
