# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.finders_api import FindersApi


class TestFindersApi(unittest.TestCase):
    """FindersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FindersApi()

    def tearDown(self) -> None:
        pass

    def test_create_finder(self) -> None:
        """Test case for create_finder

        Create Finder
        """
        pass

    def test_delete_finder(self) -> None:
        """Test case for delete_finder

        Delete Finder
        """
        pass

    def test_finder_options(self) -> None:
        """Test case for finder_options

        Finder Options
        """
        pass

    def test_finders_options(self) -> None:
        """Test case for finders_options

        Finders Options
        """
        pass

    def test_list_finders(self) -> None:
        """Test case for list_finders

        List Finders
        """
        pass

    def test_show_finder(self) -> None:
        """Test case for show_finder

        Show Finder
        """
        pass

    def test_update_finder(self) -> None:
        """Test case for update_finder

        Update Finder
        """
        pass


if __name__ == '__main__':
    unittest.main()
