# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.emails_api import EmailsApi


class TestEmailsApi(unittest.TestCase):
    """EmailsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EmailsApi()

    def tearDown(self) -> None:
        pass

    def test_create_email(self) -> None:
        """Test case for create_email

        Create Email
        """
        pass

    def test_delete_email(self) -> None:
        """Test case for delete_email

        Delete Email
        """
        pass

    def test_email_options(self) -> None:
        """Test case for email_options

        Email Options
        """
        pass

    def test_emails_options(self) -> None:
        """Test case for emails_options

        Emails Options
        """
        pass

    def test_list_emails(self) -> None:
        """Test case for list_emails

        List Emails
        """
        pass

    def test_show_email(self) -> None:
        """Test case for show_email

        Show Email
        """
        pass

    def test_update_email(self) -> None:
        """Test case for update_email

        Update Email
        """
        pass


if __name__ == '__main__':
    unittest.main()
