# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.jobs_api import JobsApi


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = JobsApi()

    def tearDown(self) -> None:
        pass

    def test_create_job(self) -> None:
        """Test case for create_job

        Create Job
        """
        pass

    def test_delete_job(self) -> None:
        """Test case for delete_job

        Delete Job
        """
        pass

    def test_job_candidates_options(self) -> None:
        """Test case for job_candidates_options

        Job Candidates Options
        """
        pass

    def test_job_candidates_relationships_options(self) -> None:
        """Test case for job_candidates_relationships_options

        Job Candidates Relationships Options
        """
        pass

    def test_job_options(self) -> None:
        """Test case for job_options

        Job Options
        """
        pass

    def test_jobs_options(self) -> None:
        """Test case for jobs_options

        Jobs Options
        """
        pass

    def test_list_job_candidates(self) -> None:
        """Test case for list_job_candidates

        List Job Candidates
        """
        pass

    def test_list_job_candidates_relationship(self) -> None:
        """Test case for list_job_candidates_relationship

        List Job Candidates Relationship
        """
        pass

    def test_list_jobs(self) -> None:
        """Test case for list_jobs

        List Jobs
        """
        pass

    def test_show_job(self) -> None:
        """Test case for show_job

        Show Job
        """
        pass

    def test_update_job(self) -> None:
        """Test case for update_job

        Update Job
        """
        pass


if __name__ == '__main__':
    unittest.main()
