# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.chat_resource_schema import ChatResourceSchema

class TestChatResourceSchema(unittest.TestCase):
    """ChatResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatResourceSchema:
        """Test ChatResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatResourceSchema`
        """
        model = ChatResourceSchema()
        if include_optional:
            return ChatResourceSchema(
                type = 'chats',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.chat_attributes_schema.ChatAttributesSchema(
                    direction = 'inbound', 
                    sender_number = '', 
                    recipient_number = '', 
                    message_sid = '', 
                    body = '', 
                    ai_response = '', 
                    short_code = '', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.chat_relationships_schema.ChatRelationshipsSchema(
                    translations = smartytalent_client.models.chat_relationships_translations_schema.ChatRelationshipsTranslationsSchema(
                        data = [
                            smartytalent_client.models.chat_relationships_translations_data_schema.ChatRelationshipsTranslationsDataSchema(
                                type = 'translations', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', )
                            ], ), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ChatResourceSchema(
                type = 'chats',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.chat_attributes_schema.ChatAttributesSchema(
                    direction = 'inbound', 
                    sender_number = '', 
                    recipient_number = '', 
                    message_sid = '', 
                    body = '', 
                    ai_response = '', 
                    short_code = '', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testChatResourceSchema(self):
        """Test ChatResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
