# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.user_attributes_schema import UserAttributesSchema

class TestUserAttributesSchema(unittest.TestCase):
    """UserAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserAttributesSchema:
        """Test UserAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserAttributesSchema`
        """
        model = UserAttributesSchema()
        if include_optional:
            return UserAttributesSchema(
                email = '',
                name = '',
                gender = '',
                locale = '',
                phone = '',
                is_system = True,
                address = { },
                settings = { },
                connections = { },
                avatar_url = '',
                status = '',
                history_events = [
                    smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                        event_id = '', 
                        event_type = 'SignIn', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        result = 'Pass', 
                        risk_level = 'Low', 
                        risk_decision = 'NoRisk', 
                        compromised_credentials = True, 
                        challenge_responses = [
                            smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                challenge = '', 
                                result = '', )
                            ], 
                        ip_address = '', 
                        device_name = '', 
                        city = '', 
                        country = '', 
                        timezone = '', 
                        new_device_used = True, 
                        event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                            feedback_value = '', 
                            provider = '', ), )
                    ],
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return UserAttributesSchema(
                email = '',
                name = '',
        )
        """

    def testUserAttributesSchema(self):
        """Test UserAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
