# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.notes_api import NotesApi


class TestNotesApi(unittest.TestCase):
    """NotesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotesApi()

    def tearDown(self) -> None:
        pass

    def test_create_note(self) -> None:
        """Test case for create_note

        Create Note
        """
        pass

    def test_delete_note(self) -> None:
        """Test case for delete_note

        Delete Note
        """
        pass

    def test_list_notes(self) -> None:
        """Test case for list_notes

        List Notes
        """
        pass

    def test_note_options(self) -> None:
        """Test case for note_options

        Note Options
        """
        pass

    def test_notes_options(self) -> None:
        """Test case for notes_options

        Notes Options
        """
        pass

    def test_show_note(self) -> None:
        """Test case for show_note

        Show Note
        """
        pass

    def test_update_note(self) -> None:
        """Test case for update_note

        Update Note
        """
        pass


if __name__ == '__main__':
    unittest.main()
