# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebhooksApi()

    def tearDown(self) -> None:
        pass

    def test_create_webhook(self) -> None:
        """Test case for create_webhook

        Create Webhook
        """
        pass

    def test_delete_webhook(self) -> None:
        """Test case for delete_webhook

        Delete Webhook
        """
        pass

    def test_list_webhooks(self) -> None:
        """Test case for list_webhooks

        List Webhooks
        """
        pass

    def test_show_webhook(self) -> None:
        """Test case for show_webhook

        Show Webhook
        """
        pass

    def test_update_webhook(self) -> None:
        """Test case for update_webhook

        Update Webhook
        """
        pass

    def test_webhook_options(self) -> None:
        """Test case for webhook_options

        Webhook Options
        """
        pass

    def test_webhooks_options(self) -> None:
        """Test case for webhooks_options

        Webhooks Options
        """
        pass


if __name__ == '__main__':
    unittest.main()
