# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody

class TestCreateMeetingAttendeeRequestBody(unittest.TestCase):
    """CreateMeetingAttendeeRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateMeetingAttendeeRequestBody:
        """Test CreateMeetingAttendeeRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMeetingAttendeeRequestBody`
        """
        model = CreateMeetingAttendeeRequestBody()
        if include_optional:
            return CreateMeetingAttendeeRequestBody(
                data = smartytalent_client.models.create_meeting_attendee_request_body_data.CreateMeetingAttendeeRequestBodyData(
                    type = 'attendees', 
                    attributes = smartytalent_client.models.meeting_attendee_attributes_schema.MeetingAttendeeAttributesSchema(
                        name = '', 
                        email = '', 
                        role = '', 
                        external_user_id = '', ), )
            )
        else:
            return CreateMeetingAttendeeRequestBody(
                data = smartytalent_client.models.create_meeting_attendee_request_body_data.CreateMeetingAttendeeRequestBodyData(
                    type = 'attendees', 
                    attributes = smartytalent_client.models.meeting_attendee_attributes_schema.MeetingAttendeeAttributesSchema(
                        name = '', 
                        email = '', 
                        role = '', 
                        external_user_id = '', ), ),
        )
        """

    def testCreateMeetingAttendeeRequestBody(self):
        """Test CreateMeetingAttendeeRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
