# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.triggers_api import TriggersApi


class TestTriggersApi(unittest.TestCase):
    """TriggersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TriggersApi()

    def tearDown(self) -> None:
        pass

    def test_create_trigger(self) -> None:
        """Test case for create_trigger

        Create Trigger
        """
        pass

    def test_delete_trigger(self) -> None:
        """Test case for delete_trigger

        Delete Trigger
        """
        pass

    def test_list_triggers(self) -> None:
        """Test case for list_triggers

        List Triggers
        """
        pass

    def test_show_trigger(self) -> None:
        """Test case for show_trigger

        Show Trigger
        """
        pass

    def test_update_trigger(self) -> None:
        """Test case for update_trigger

        Update Trigger
        """
        pass


if __name__ == '__main__':
    unittest.main()
