# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.personas_api import PersonasApi


class TestPersonasApi(unittest.TestCase):
    """PersonasApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PersonasApi()

    def tearDown(self) -> None:
        pass

    def test_create_persona(self) -> None:
        """Test case for create_persona

        Create Persona
        """
        pass

    def test_delete_persona(self) -> None:
        """Test case for delete_persona

        Delete Persona
        """
        pass

    def test_list_personas(self) -> None:
        """Test case for list_personas

        List Personas
        """
        pass

    def test_persona_options(self) -> None:
        """Test case for persona_options

        Persona Options
        """
        pass

    def test_personas_options(self) -> None:
        """Test case for personas_options

        Personas Options
        """
        pass

    def test_show_persona(self) -> None:
        """Test case for show_persona

        Show Persona
        """
        pass

    def test_update_persona(self) -> None:
        """Test case for update_persona

        Update Persona
        """
        pass


if __name__ == '__main__':
    unittest.main()
