# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.webhooks_schema import WebhooksSchema

class TestWebhooksSchema(unittest.TestCase):
    """WebhooksSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebhooksSchema:
        """Test WebhooksSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebhooksSchema`
        """
        model = WebhooksSchema()
        if include_optional:
            return WebhooksSchema(
                data = [
                    null
                    ],
                links = smartytalent_client.models.resources_links_schema.ResourcesLinksSchema(
                    self = '', 
                    related = '', 
                    first = '', 
                    prev = '', 
                    next = '', 
                    last = '', ),
                meta = smartytalent_client.models.resources_meta_schema.ResourcesMetaSchema(
                    page = smartytalent_client.models.resources_meta_page_schema.ResourcesMetaPageSchema(
                        cursor = 'MjhkNDljZTc0MzMxNGExOTgzMThmYzlmMWZhZDE0N2YtMQ==', 
                        size = 2, 
                        number = 2, 
                        total_items = 10, 
                        total_pages = 5, ), 
                    count = smartytalent_client.models.resources_meta_count_schema.ResourcesMetaCountSchema(), )
            )
        else:
            return WebhooksSchema(
        )
        """

    def testWebhooksSchema(self):
        """Test WebhooksSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
