# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.conversations_api import ConversationsApi


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConversationsApi()

    def tearDown(self) -> None:
        pass

    def test_conversation_options(self) -> None:
        """Test case for conversation_options

        Conversation Options
        """
        pass

    def test_conversations_options(self) -> None:
        """Test case for conversations_options

        Conversations Options
        """
        pass

    def test_create_conversation(self) -> None:
        """Test case for create_conversation

        Create Conversation
        """
        pass

    def test_delete_conversation(self) -> None:
        """Test case for delete_conversation

        Delete Conversation
        """
        pass

    def test_list_conversations(self) -> None:
        """Test case for list_conversations

        List Conversations
        """
        pass

    def test_show_conversation(self) -> None:
        """Test case for show_conversation

        Show Conversation
        """
        pass

    def test_update_conversation(self) -> None:
        """Test case for update_conversation

        Update Conversation
        """
        pass


if __name__ == '__main__':
    unittest.main()
