# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema

class TestMeetingAttendeeResourceSchema(unittest.TestCase):
    """MeetingAttendeeResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MeetingAttendeeResourceSchema:
        """Test MeetingAttendeeResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MeetingAttendeeResourceSchema`
        """
        model = MeetingAttendeeResourceSchema()
        if include_optional:
            return MeetingAttendeeResourceSchema(
                type = 'attendees',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.meeting_attendee_response_attributes_schema.MeetingAttendeeResponseAttributesSchema(
                    chime_attendee_id = '', 
                    external_user_id = '', 
                    join_token = '', 
                    name = '', 
                    email = '', 
                    role = '', 
                    chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), ),
                relationships = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships.MeetingAttendeeResourceSchema_allOf_relationships(
                    meeting = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting.MeetingAttendeeResourceSchema_allOf_relationships_meeting(
                        data = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data.MeetingAttendeeResourceSchema_allOf_relationships_meeting_data(
                            type = 'meetings', 
                            id = '', ), ), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return MeetingAttendeeResourceSchema(
                type = 'attendees',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.meeting_attendee_response_attributes_schema.MeetingAttendeeResponseAttributesSchema(
                    chime_attendee_id = '', 
                    external_user_id = '', 
                    join_token = '', 
                    name = '', 
                    email = '', 
                    role = '', 
                    chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), ),
        )
        """

    def testMeetingAttendeeResourceSchema(self):
        """Test MeetingAttendeeResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
