# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.meetings_api import MeetingsApi


class TestMeetingsApi(unittest.TestCase):
    """MeetingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MeetingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_meeting(self) -> None:
        """Test case for create_meeting

        Create Meeting
        """
        pass

    def test_create_meeting_ai_session(self) -> None:
        """Test case for create_meeting_ai_session

        Create Meeting AI Session
        """
        pass

    def test_create_meeting_attendee(self) -> None:
        """Test case for create_meeting_attendee

        Create Meeting Attendee
        """
        pass

    def test_delete_meeting(self) -> None:
        """Test case for delete_meeting

        Delete Meeting
        """
        pass

    def test_list_meetings(self) -> None:
        """Test case for list_meetings

        List Meetings
        """
        pass

    def test_meeting_ai_session_options(self) -> None:
        """Test case for meeting_ai_session_options

        Meeting AI Session Options
        """
        pass

    def test_meeting_attendees_options(self) -> None:
        """Test case for meeting_attendees_options

        Meeting Attendees Options
        """
        pass

    def test_meeting_lobby_options(self) -> None:
        """Test case for meeting_lobby_options

        Meeting Lobby Options
        """
        pass

    def test_meeting_options(self) -> None:
        """Test case for meeting_options

        Meeting Options
        """
        pass

    def test_meeting_transcription(self) -> None:
        """Test case for meeting_transcription

        Manage Meeting Transcription
        """
        pass

    def test_meeting_transcription_options(self) -> None:
        """Test case for meeting_transcription_options

        Meeting Transcription Options
        """
        pass

    def test_meetings_options(self) -> None:
        """Test case for meetings_options

        Meetings Options
        """
        pass

    def test_show_meeting(self) -> None:
        """Test case for show_meeting

        Show Meeting
        """
        pass

    def test_show_meeting_lobby(self) -> None:
        """Test case for show_meeting_lobby

        Show Meeting Lobby
        """
        pass

    def test_update_meeting(self) -> None:
        """Test case for update_meeting

        Update Meeting
        """
        pass


if __name__ == '__main__':
    unittest.main()
