# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.forms_api import FormsApi


class TestFormsApi(unittest.TestCase):
    """FormsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FormsApi()

    def tearDown(self) -> None:
        pass

    def test_create_form(self) -> None:
        """Test case for create_form

        Create Form
        """
        pass

    def test_delete_form(self) -> None:
        """Test case for delete_form

        Delete Form
        """
        pass

    def test_form_options(self) -> None:
        """Test case for form_options

        Form Options
        """
        pass

    def test_forms_options(self) -> None:
        """Test case for forms_options

        Forms Options
        """
        pass

    def test_list_forms(self) -> None:
        """Test case for list_forms

        List Forms
        """
        pass

    def test_show_form(self) -> None:
        """Test case for show_form

        Show Form
        """
        pass

    def test_update_form(self) -> None:
        """Test case for update_form

        Update Form
        """
        pass


if __name__ == '__main__':
    unittest.main()
