# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody

class TestUpdateCandidateRequestBody(unittest.TestCase):
    """UpdateCandidateRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateCandidateRequestBody:
        """Test UpdateCandidateRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateCandidateRequestBody`
        """
        model = UpdateCandidateRequestBody()
        if include_optional:
            return UpdateCandidateRequestBody(
                data = smartytalent_client.models.update_candidate_request_body_data.UpdateCandidateRequestBodyData(
                    type = 'candidates', 
                    id = '', 
                    attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        status = 'active', 
                        stage = 'sourced', 
                        age = '', 
                        gender = '', 
                        source = '', 
                        short_code = '', 
                        language_code = '', 
                        recommendation_status_code = 56, 
                        overall_match_rating = 56, 
                        prev_overall_match_rating = 56, 
                        ttl = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        job_position_title = {
                            'key' : ''
                            }, 
                        rejection_ticket = {
                            'key' : ''
                            }, 
                        recommendation_status = {
                            'key' : None
                            }, 
                        overall_assessment = {
                            'key' : None
                            }, 
                        next_steps = {
                            'key' : None
                            }, 
                        insights_and_analysis = {
                            'key' : None
                            }, 
                        keywords = {
                            'key' : None
                            }, 
                        availability = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                expected = [
                                    None
                                    ], 
                                received = [
                                    None
                                    ], 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        certifications = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, ), )
            )
        else:
            return UpdateCandidateRequestBody(
                data = smartytalent_client.models.update_candidate_request_body_data.UpdateCandidateRequestBodyData(
                    type = 'candidates', 
                    id = '', 
                    attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        status = 'active', 
                        stage = 'sourced', 
                        age = '', 
                        gender = '', 
                        source = '', 
                        short_code = '', 
                        language_code = '', 
                        recommendation_status_code = 56, 
                        overall_match_rating = 56, 
                        prev_overall_match_rating = 56, 
                        ttl = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        job_position_title = {
                            'key' : ''
                            }, 
                        rejection_ticket = {
                            'key' : ''
                            }, 
                        recommendation_status = {
                            'key' : None
                            }, 
                        overall_assessment = {
                            'key' : None
                            }, 
                        next_steps = {
                            'key' : None
                            }, 
                        insights_and_analysis = {
                            'key' : None
                            }, 
                        keywords = {
                            'key' : None
                            }, 
                        availability = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                expected = [
                                    None
                                    ], 
                                received = [
                                    None
                                    ], 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        certifications = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, ), ),
        )
        """

    def testUpdateCandidateRequestBody(self):
        """Test UpdateCandidateRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
