# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody

class TestCreateMeetingAiSessionRequestBody(unittest.TestCase):
    """CreateMeetingAiSessionRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateMeetingAiSessionRequestBody:
        """Test CreateMeetingAiSessionRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMeetingAiSessionRequestBody`
        """
        model = CreateMeetingAiSessionRequestBody()
        if include_optional:
            return CreateMeetingAiSessionRequestBody(
                data = smartytalent_client.models.create_meeting_ai_session_request_body_data.CreateMeetingAiSessionRequestBodyData(
                    type = 'ai-sessions', 
                    attributes = smartytalent_client.models.meeting_ai_session_settings_schema.MeetingAiSessionSettingsSchema(
                        mode = 'translator', 
                        source_language = '', 
                        target_language = '', 
                        language = '', ), )
            )
        else:
            return CreateMeetingAiSessionRequestBody(
                data = smartytalent_client.models.create_meeting_ai_session_request_body_data.CreateMeetingAiSessionRequestBodyData(
                    type = 'ai-sessions', 
                    attributes = smartytalent_client.models.meeting_ai_session_settings_schema.MeetingAiSessionSettingsSchema(
                        mode = 'translator', 
                        source_language = '', 
                        target_language = '', 
                        language = '', ), ),
        )
        """

    def testCreateMeetingAiSessionRequestBody(self):
        """Test CreateMeetingAiSessionRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
