# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema

class TestCandidateCriteriaSchema(unittest.TestCase):
    """CandidateCriteriaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CandidateCriteriaSchema:
        """Test CandidateCriteriaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CandidateCriteriaSchema`
        """
        model = CandidateCriteriaSchema()
        if include_optional:
            return CandidateCriteriaSchema(
                name = '',
                description = '',
                priority = 'low',
                priority_confidence = 'low',
                priority_reasoning = '',
                expected = [
                    None
                    ],
                received = [
                    None
                    ],
                weight = '',
                rating = 1.337,
                prev_rating = 1.337,
                data_available = True,
                comparison_confidence = '',
                comparison_reasoning = '',
                is_comparison_assumed = True
            )
        else:
            return CandidateCriteriaSchema(
        )
        """

    def testCandidateCriteriaSchema(self):
        """Test CandidateCriteriaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
