# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.assessments_api import AssessmentsApi


class TestAssessmentsApi(unittest.TestCase):
    """AssessmentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AssessmentsApi()

    def tearDown(self) -> None:
        pass

    def test_assessment_options(self) -> None:
        """Test case for assessment_options

        Assessment Options
        """
        pass

    def test_assessments_options(self) -> None:
        """Test case for assessments_options

        Assessments Options
        """
        pass

    def test_create_assessment(self) -> None:
        """Test case for create_assessment

        Create Assessment
        """
        pass

    def test_delete_assessment(self) -> None:
        """Test case for delete_assessment

        Delete Assessment
        """
        pass

    def test_list_assessments(self) -> None:
        """Test case for list_assessments

        List Assessments
        """
        pass

    def test_show_assessment(self) -> None:
        """Test case for show_assessment

        Show Assessment
        """
        pass

    def test_update_assessment(self) -> None:
        """Test case for update_assessment

        Update Assessment
        """
        pass


if __name__ == '__main__':
    unittest.main()
