# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.runs_api import RunsApi


class TestRunsApi(unittest.TestCase):
    """RunsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RunsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_run(self) -> None:
        """Test case for cancel_run

        Cancel Run
        """
        pass

    def test_create_run(self) -> None:
        """Test case for create_run

        Create Run
        """
        pass

    def test_list_runs(self) -> None:
        """Test case for list_runs

        List Runs
        """
        pass

    def test_retry_run(self) -> None:
        """Test case for retry_run

        Retry Run
        """
        pass

    def test_show_run(self) -> None:
        """Test case for show_run

        Show Run
        """
        pass


if __name__ == '__main__':
    unittest.main()
