# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship

class TestListTalentCandidatesRelationship(unittest.TestCase):
    """ListTalentCandidatesRelationship unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListTalentCandidatesRelationship:
        """Test ListTalentCandidatesRelationship
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListTalentCandidatesRelationship`
        """
        model = ListTalentCandidatesRelationship()
        if include_optional:
            return ListTalentCandidatesRelationship(
                data = [
                    smartytalent_client.models.candidate_relationships_schema.CandidateRelationshipsSchema(
                        job = smartytalent_client.models.candidate_relationships_job_schema.CandidateRelationshipsJobSchema(
                            data = smartytalent_client.models.candidate_relationships_job_data_schema.CandidateRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), 
                        talent = smartytalent_client.models.candidate_relationships_talent_schema.CandidateRelationshipsTalentSchema(), 
                        translations = smartytalent_client.models.candidate_relationships_translations_schema.CandidateRelationshipsTranslationsSchema(), 
                        operations = smartytalent_client.models.candidate_relationships_operations_schema.CandidateRelationshipsOperationsSchema(), )
                    ],
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ListTalentCandidatesRelationship(
        )
        """

    def testListTalentCandidatesRelationship(self):
        """Test ListTalentCandidatesRelationship"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
