# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class UserHistoryEventSchema(BaseModel):
    """
    UserHistoryEventSchema
    """ # noqa: E501
    event_id: Optional[StrictStr] = Field(default=None, alias="eventId")
    event_type: Optional[StrictStr] = Field(default=None, alias="eventType")
    timestamp: Optional[datetime] = None
    result: Optional[StrictStr] = None
    risk_level: Optional[StrictStr] = Field(default=None, alias="riskLevel")
    risk_decision: Optional[StrictStr] = Field(default=None, alias="riskDecision")
    compromised_credentials: Optional[StrictBool] = Field(default=None, alias="compromisedCredentials")
    challenge_responses: Optional[List[UserHistoryEventSchemaChallengeResponsesInner]] = Field(default=None, alias="challengeResponses")
    ip_address: Optional[StrictStr] = Field(default=None, alias="ipAddress")
    device_name: Optional[StrictStr] = Field(default=None, alias="deviceName")
    city: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    timezone: Optional[StrictStr] = None
    new_device_used: Optional[StrictBool] = Field(default=None, alias="newDeviceUsed")
    event_feedback: Optional[UserHistoryEventSchemaEventFeedback] = Field(default=None, alias="eventFeedback")
    __properties: ClassVar[List[str]] = ["eventId", "eventType", "timestamp", "result", "riskLevel", "riskDecision", "compromisedCredentials", "challengeResponses", "ipAddress", "deviceName", "city", "country", "timezone", "newDeviceUsed", "eventFeedback"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserHistoryEventSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in challenge_responses (list)
        _items = []
        if self.challenge_responses:
            for _item_challenge_responses in self.challenge_responses:
                if _item_challenge_responses:
                    _items.append(_item_challenge_responses.to_dict())
            _dict['challengeResponses'] = _items
        # override the default output from pydantic by calling `to_dict()` of event_feedback
        if self.event_feedback:
            _dict['eventFeedback'] = self.event_feedback.to_dict()
        # set to None if event_feedback (nullable) is None
        # and model_fields_set contains the field
        if self.event_feedback is None and "event_feedback" in self.model_fields_set:
            _dict['eventFeedback'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserHistoryEventSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "eventId": obj.get("eventId"),
            "eventType": obj.get("eventType"),
            "timestamp": obj.get("timestamp"),
            "result": obj.get("result"),
            "riskLevel": obj.get("riskLevel"),
            "riskDecision": obj.get("riskDecision"),
            "compromisedCredentials": obj.get("compromisedCredentials"),
            "challengeResponses": [UserHistoryEventSchemaChallengeResponsesInner.from_dict(_item) for _item in obj["challengeResponses"]] if obj.get("challengeResponses") is not None else None,
            "ipAddress": obj.get("ipAddress"),
            "deviceName": obj.get("deviceName"),
            "city": obj.get("city"),
            "country": obj.get("country"),
            "timezone": obj.get("timezone"),
            "newDeviceUsed": obj.get("newDeviceUsed"),
            "eventFeedback": UserHistoryEventSchemaEventFeedback.from_dict(obj["eventFeedback"]) if obj.get("eventFeedback") is not None else None
        })
        return _obj


