# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema

class TestFinderRelationshipsSchema(unittest.TestCase):
    """FinderRelationshipsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FinderRelationshipsSchema:
        """Test FinderRelationshipsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FinderRelationshipsSchema`
        """
        model = FinderRelationshipsSchema()
        if include_optional:
            return FinderRelationshipsSchema(
                jobs = smartytalent_client.models.finder_relationships_jobs_schema.FinderRelationshipsJobsSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_jobs_data_schema.FinderRelationshipsJobsDataSchema(
                            type = 'jobs', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                users = smartytalent_client.models.finder_relationships_users_schema.FinderRelationshipsUsersSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_users_data_schema.FinderRelationshipsUsersDataSchema(
                            type = 'users', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                talents = smartytalent_client.models.finder_relationships_talents_schema.FinderRelationshipsTalentsSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_talents_data_schema.FinderRelationshipsTalentsDataSchema(
                            type = 'talents', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], ),
                candidates = smartytalent_client.models.finder_relationships_candidates_schema.FinderRelationshipsCandidatesSchema(
                    data = [
                        smartytalent_client.models.finder_relationships_candidates_data_schema.FinderRelationshipsCandidatesDataSchema(
                            type = 'candidates', 
                            id = '655cde5c9931802df628f3d2de8ca681-2', )
                        ], )
            )
        else:
            return FinderRelationshipsSchema(
        )
        """

    def testFinderRelationshipsSchema(self):
        """Test FinderRelationshipsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
