# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData

class TestCreateNotificationRequestBodyData(unittest.TestCase):
    """CreateNotificationRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateNotificationRequestBodyData:
        """Test CreateNotificationRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateNotificationRequestBodyData`
        """
        model = CreateNotificationRequestBodyData()
        if include_optional:
            return CreateNotificationRequestBodyData(
                type = 'notifications',
                attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                    title = '', 
                    subtitle = '', 
                    category = 'general', 
                    status = 'unread', 
                    avatar_icon = '', 
                    avatar_text = '', 
                    avatar_image = '', 
                    avatar_color = 'primary', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                relationships = smartytalent_client.models.notification_relationships_schema.NotificationRelationshipsSchema(
                    users = smartytalent_client.models.notification_relationships_schema_users.NotificationRelationshipsSchema_users(
                        data = [
                            smartytalent_client.models.notification_relationships_schema_users_data_inner.NotificationRelationshipsSchema_users_data_inner(
                                type = 'users', 
                                id = '655cde5c9931802df628f3d2de8ca681-1', )
                            ], ), )
            )
        else:
            return CreateNotificationRequestBodyData(
                type = 'notifications',
                attributes = smartytalent_client.models.notification_attributes_schema.NotificationAttributesSchema(
                    title = '', 
                    subtitle = '', 
                    category = 'general', 
                    status = 'unread', 
                    avatar_icon = '', 
                    avatar_text = '', 
                    avatar_image = '', 
                    avatar_color = 'primary', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testCreateNotificationRequestBodyData(self):
        """Test CreateNotificationRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
