# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.candidates_api import CandidatesApi


class TestCandidatesApi(unittest.TestCase):
    """CandidatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CandidatesApi()

    def tearDown(self) -> None:
        pass

    def test_candidate_jobs_options(self) -> None:
        """Test case for candidate_jobs_options

        Candidate Jobs Options
        """
        pass

    def test_candidate_jobs_relationships_options(self) -> None:
        """Test case for candidate_jobs_relationships_options

        Candidate Jobs Relationships Options
        """
        pass

    def test_candidate_options(self) -> None:
        """Test case for candidate_options

        Candidate Options
        """
        pass

    def test_candidate_talents_options(self) -> None:
        """Test case for candidate_talents_options

        Candidate Talents Options
        """
        pass

    def test_candidate_talents_relationships_options(self) -> None:
        """Test case for candidate_talents_relationships_options

        Candidate Talents Relationships Options
        """
        pass

    def test_candidates_options(self) -> None:
        """Test case for candidates_options

        Candidates Options
        """
        pass

    def test_create_candidate(self) -> None:
        """Test case for create_candidate

        Create Candidate
        """
        pass

    def test_delete_candidate(self) -> None:
        """Test case for delete_candidate

        Delete Candidate
        """
        pass

    def test_list_candidate_jobs(self) -> None:
        """Test case for list_candidate_jobs

        List Candidate Jobs
        """
        pass

    def test_list_candidate_jobs_relationship(self) -> None:
        """Test case for list_candidate_jobs_relationship

        List Candidate Jobs Relationship
        """
        pass

    def test_list_candidate_talents(self) -> None:
        """Test case for list_candidate_talents

        List Candidate Talents
        """
        pass

    def test_list_candidate_talents_relationship(self) -> None:
        """Test case for list_candidate_talents_relationship

        List Candidate Talents Relationship
        """
        pass

    def test_list_candidates(self) -> None:
        """Test case for list_candidates

        List Candidates
        """
        pass

    def test_show_candidate(self) -> None:
        """Test case for show_candidate

        Show Candidate
        """
        pass

    def test_update_candidate(self) -> None:
        """Test case for update_candidate

        Update Candidate
        """
        pass


if __name__ == '__main__':
    unittest.main()
