# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.apikeys_api import ApikeysApi


class TestApikeysApi(unittest.TestCase):
    """ApikeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApikeysApi()

    def tearDown(self) -> None:
        pass

    def test_apikey_options(self) -> None:
        """Test case for apikey_options

        Apikey Options
        """
        pass

    def test_apikeys_options(self) -> None:
        """Test case for apikeys_options

        Apikeys Options
        """
        pass

    def test_create_apikey(self) -> None:
        """Test case for create_apikey

        Create Apikey
        """
        pass

    def test_delete_apikey(self) -> None:
        """Test case for delete_apikey

        Delete Apikey
        """
        pass

    def test_list_apikeys(self) -> None:
        """Test case for list_apikeys

        List Apikeys
        """
        pass

    def test_show_apikey(self) -> None:
        """Test case for show_apikey

        Show Apikey
        """
        pass

    def test_update_apikey(self) -> None:
        """Test case for update_apikey

        Update Apikey
        """
        pass


if __name__ == '__main__':
    unittest.main()
