# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody

class TestUpdateEmailRequestBody(unittest.TestCase):
    """UpdateEmailRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateEmailRequestBody:
        """Test UpdateEmailRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateEmailRequestBody`
        """
        model = UpdateEmailRequestBody()
        if include_optional:
            return UpdateEmailRequestBody(
                data = smartytalent_client.models.update_email_request_body_data.UpdateEmailRequestBodyData(
                    type = 'emails', 
                    id = '', 
                    attributes = smartytalent_client.models.email_attributes_schema.EmailAttributesSchema(
                        name = '', 
                        status = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
            )
        else:
            return UpdateEmailRequestBody(
                data = smartytalent_client.models.update_email_request_body_data.UpdateEmailRequestBodyData(
                    type = 'emails', 
                    id = '', 
                    attributes = smartytalent_client.models.email_attributes_schema.EmailAttributesSchema(
                        name = '', 
                        status = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), ),
        )
        """

    def testUpdateEmailRequestBody(self):
        """Test UpdateEmailRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
