# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_cors_timeline_entry(self) -> None:
        """Test case for cors_timeline_entry

        CORS support for Timeline Entry
        """
        pass

    def test_cors_timeline_rollback(self) -> None:
        """Test case for cors_timeline_rollback

        CORS support for Timeline Rollback
        """
        pass

    def test_cors_timelines(self) -> None:
        """Test case for cors_timelines

        CORS support for Timelines
        """
        pass


if __name__ == '__main__':
    unittest.main()
