# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship

class TestListRoleUsersRelationship(unittest.TestCase):
    """ListRoleUsersRelationship unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListRoleUsersRelationship:
        """Test ListRoleUsersRelationship
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListRoleUsersRelationship`
        """
        model = ListRoleUsersRelationship()
        if include_optional:
            return ListRoleUsersRelationship(
                data = [
                    smartytalent_client.models.user_relationships_schema.UserRelationshipsSchema(
                        role = smartytalent_client.models.user_relationships_role_schema.UserRelationshipsRoleSchema(
                            data = smartytalent_client.models.user_relationships_role_data_schema.UserRelationshipsRoleDataSchema(
                                type = 'roles', 
                                id = '655cde5c9931802df628f3d2de8ca681-1', ), ), 
                        jobs = smartytalent_client.models.user_relationships_jobs_schema.UserRelationshipsJobsSchema(), 
                        apikeys = smartytalent_client.models.user_relationships_apikeys_schema.UserRelationshipsApikeysSchema(), )
                    ],
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ListRoleUsersRelationship(
        )
        """

    def testListRoleUsersRelationship(self):
        """Test ListRoleUsersRelationship"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
