# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.reports_api import ReportsApi


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()

    def tearDown(self) -> None:
        pass

    def test_create_report(self) -> None:
        """Test case for create_report

        Create Report
        """
        pass

    def test_delete_report(self) -> None:
        """Test case for delete_report

        Delete Report
        """
        pass

    def test_list_reports(self) -> None:
        """Test case for list_reports

        List Reports
        """
        pass

    def test_report_options(self) -> None:
        """Test case for report_options

        Report Options
        """
        pass

    def test_reports_options(self) -> None:
        """Test case for reports_options

        Reports Options
        """
        pass

    def test_show_report(self) -> None:
        """Test case for show_report

        Show Report
        """
        pass

    def test_update_report(self) -> None:
        """Test case for update_report

        Update Report
        """
        pass


if __name__ == '__main__':
    unittest.main()
