# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.files_api import FilesApi


class TestFilesApi(unittest.TestCase):
    """FilesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FilesApi()

    def tearDown(self) -> None:
        pass

    def test_create_file(self) -> None:
        """Test case for create_file

        Create File
        """
        pass

    def test_delete_file(self) -> None:
        """Test case for delete_file

        Delete File
        """
        pass

    def test_file_options(self) -> None:
        """Test case for file_options

        File Options
        """
        pass

    def test_files_options(self) -> None:
        """Test case for files_options

        Files Options
        """
        pass

    def test_list_files(self) -> None:
        """Test case for list_files

        List Files
        """
        pass

    def test_show_file(self) -> None:
        """Test case for show_file

        Show File
        """
        pass

    def test_update_file(self) -> None:
        """Test case for update_file

        Update File
        """
        pass


if __name__ == '__main__':
    unittest.main()
