# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema

class TestTalentAttributesDesiredContractLengthSchema(unittest.TestCase):
    """TalentAttributesDesiredContractLengthSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TalentAttributesDesiredContractLengthSchema:
        """Test TalentAttributesDesiredContractLengthSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TalentAttributesDesiredContractLengthSchema`
        """
        model = TalentAttributesDesiredContractLengthSchema()
        if include_optional:
            return TalentAttributesDesiredContractLengthSchema(
                duration = '',
                is_assumed = True,
                confidence = 'Low',
                flexibility = '',
                reasoning = ''
            )
        else:
            return TalentAttributesDesiredContractLengthSchema(
        )
        """

    def testTalentAttributesDesiredContractLengthSchema(self):
        """Test TalentAttributesDesiredContractLengthSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
