# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class TenantUploadAttributesSchema(BaseModel):
    """
    TenantUploadAttributesSchema
    """ # noqa: E501
    upload_url: Optional[StrictStr] = Field(default=None, alias="uploadUrl")
    s3_key: Optional[StrictStr] = Field(default=None, alias="s3Key")
    url: Optional[StrictStr] = None
    content_type: Optional[StrictStr] = Field(default=None, alias="contentType")
    purpose: Optional[StrictStr] = None
    expires_in: Optional[StrictInt] = Field(default=None, alias="expiresIn")
    max_file_size: Optional[StrictInt] = Field(default=None, description="Maximum file size in bytes", alias="maxFileSize")
    __properties: ClassVar[List[str]] = ["uploadUrl", "s3Key", "url", "contentType", "purpose", "expiresIn", "maxFileSize"]

    @field_validator('purpose')
    def purpose_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['logo', 'background', 'favicon']):
            raise ValueError("must be one of enum values ('logo', 'background', 'favicon')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantUploadAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantUploadAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uploadUrl": obj.get("uploadUrl"),
            "s3Key": obj.get("s3Key"),
            "url": obj.get("url"),
            "contentType": obj.get("contentType"),
            "purpose": obj.get("purpose"),
            "expiresIn": obj.get("expiresIn"),
            "maxFileSize": obj.get("maxFileSize")
        })
        return _obj


