# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.links_api import LinksApi


class TestLinksApi(unittest.TestCase):
    """LinksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LinksApi()

    def tearDown(self) -> None:
        pass

    def test_create_link(self) -> None:
        """Test case for create_link

        Create Link
        """
        pass

    def test_delete_link(self) -> None:
        """Test case for delete_link

        Delete Link
        """
        pass

    def test_link_options(self) -> None:
        """Test case for link_options

        Link Options
        """
        pass

    def test_links_options(self) -> None:
        """Test case for links_options

        Links Options
        """
        pass

    def test_list_links(self) -> None:
        """Test case for list_links

        List Links
        """
        pass

    def test_show_link(self) -> None:
        """Test case for show_link

        Show Link
        """
        pass

    def test_update_link(self) -> None:
        """Test case for update_link

        Update Link
        """
        pass


if __name__ == '__main__':
    unittest.main()
