# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.assessment_relationships_schema import AssessmentRelationshipsSchema

class TestAssessmentRelationshipsSchema(unittest.TestCase):
    """AssessmentRelationshipsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AssessmentRelationshipsSchema:
        """Test AssessmentRelationshipsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AssessmentRelationshipsSchema`
        """
        model = AssessmentRelationshipsSchema()
        if include_optional:
            return AssessmentRelationshipsSchema(
                candidate = smartytalent_client.models.assessment_relationships_candidate_schema.AssessmentRelationshipsCandidateSchema(
                    data = smartytalent_client.models.assessment_relationships_candidate_data_schema.AssessmentRelationshipsCandidateDataSchema(
                        type = 'candidates', 
                        id = '655cde5c9931802df628f3d2de8ca681-2', ), ),
                job = smartytalent_client.models.assessment_relationships_job_schema.AssessmentRelationshipsJobSchema(
                    data = smartytalent_client.models.assessment_relationships_job_data_schema.AssessmentRelationshipsJobDataSchema(
                        type = 'jobs', 
                        id = '655cde5c9931802df628f3d2de8ca681-2', ), )
            )
        else:
            return AssessmentRelationshipsSchema(
        )
        """

    def testAssessmentRelationshipsSchema(self):
        """Test AssessmentRelationshipsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
