# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class UserAttributesSchema(BaseModel):
    """
    UserAttributesSchema
    """ # noqa: E501
    email: StrictStr
    name: StrictStr
    gender: Optional[StrictStr] = None
    locale: Optional[StrictStr] = None
    phone: Optional[StrictStr] = None
    is_system: Optional[StrictBool] = Field(default=None, alias="isSystem")
    address: Optional[Dict[str, Any]] = None
    settings: Optional[Dict[str, Any]] = None
    connections: Optional[Dict[str, Any]] = None
    avatar_url: Optional[StrictStr] = Field(default=None, alias="avatarUrl")
    status: Optional[StrictStr] = None
    history_events: Optional[List[UserHistoryEventSchema]] = Field(default=None, alias="historyEvents")
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["email", "name", "gender", "locale", "phone", "isSystem", "address", "settings", "connections", "avatarUrl", "status", "historyEvents", "timestamps"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in history_events (list)
        _items = []
        if self.history_events:
            for _item_history_events in self.history_events:
                if _item_history_events:
                    _items.append(_item_history_events.to_dict())
            _dict['historyEvents'] = _items
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "email": obj.get("email"),
            "name": obj.get("name"),
            "gender": obj.get("gender"),
            "locale": obj.get("locale"),
            "phone": obj.get("phone"),
            "isSystem": obj.get("isSystem"),
            "address": obj.get("address"),
            "settings": obj.get("settings"),
            "connections": obj.get("connections"),
            "avatarUrl": obj.get("avatarUrl"),
            "status": obj.get("status"),
            "historyEvents": [UserHistoryEventSchema.from_dict(_item) for _item in obj["historyEvents"]] if obj.get("historyEvents") is not None else None,
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj


