# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.users_api import UsersApi


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UsersApi()

    def tearDown(self) -> None:
        pass

    def test_create_user(self) -> None:
        """Test case for create_user

        Create User
        """
        pass

    def test_create_user_upload(self) -> None:
        """Test case for create_user_upload

        Create User Upload
        """
        pass

    def test_delete_user(self) -> None:
        """Test case for delete_user

        Delete User
        """
        pass

    def test_list_user_apikeys(self) -> None:
        """Test case for list_user_apikeys

        List User Apikeys
        """
        pass

    def test_list_user_apikeys_relationship(self) -> None:
        """Test case for list_user_apikeys_relationship

        List User Apikeys Relationship
        """
        pass

    def test_list_user_jobs(self) -> None:
        """Test case for list_user_jobs

        List User Jobs
        """
        pass

    def test_list_user_jobs_relationship(self) -> None:
        """Test case for list_user_jobs_relationship

        List User Jobs Relationship
        """
        pass

    def test_list_user_roles(self) -> None:
        """Test case for list_user_roles

        List User Roles
        """
        pass

    def test_list_user_roles_relationship(self) -> None:
        """Test case for list_user_roles_relationship

        List User Roles Relationship
        """
        pass

    def test_list_users(self) -> None:
        """Test case for list_users

        List Users
        """
        pass

    def test_show_user(self) -> None:
        """Test case for show_user

        Show User
        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        Update User
        """
        pass

    def test_user_apikeys_options(self) -> None:
        """Test case for user_apikeys_options

        User Apikeys Options
        """
        pass

    def test_user_apikeys_relationships_options(self) -> None:
        """Test case for user_apikeys_relationships_options

        User Apikeys Relationships Options
        """
        pass

    def test_user_jobs_options(self) -> None:
        """Test case for user_jobs_options

        User Jobs Options
        """
        pass

    def test_user_jobs_relationships_options(self) -> None:
        """Test case for user_jobs_relationships_options

        User Jobs Relationships Options
        """
        pass

    def test_user_options(self) -> None:
        """Test case for user_options

        User Options
        """
        pass

    def test_user_roles_options(self) -> None:
        """Test case for user_roles_options

        User Roles Options
        """
        pass

    def test_user_roles_relationships_options(self) -> None:
        """Test case for user_roles_relationships_options

        User Roles Relationships Options
        """
        pass

    def test_user_uploads_options(self) -> None:
        """Test case for user_uploads_options

        User Uploads Options
        """
        pass

    def test_users_options(self) -> None:
        """Test case for users_options

        Users Options
        """
        pass


if __name__ == '__main__':
    unittest.main()
