# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.chats_api import ChatsApi


class TestChatsApi(unittest.TestCase):
    """ChatsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatsApi()

    def tearDown(self) -> None:
        pass

    def test_chat_options(self) -> None:
        """Test case for chat_options

        Chat Options
        """
        pass

    def test_chats_options(self) -> None:
        """Test case for chats_options

        Chats Options
        """
        pass

    def test_create_chat(self) -> None:
        """Test case for create_chat

        Create Chat
        """
        pass

    def test_delete_chat(self) -> None:
        """Test case for delete_chat

        Delete Chat
        """
        pass

    def test_list_chats(self) -> None:
        """Test case for list_chats

        List Chats
        """
        pass

    def test_show_chat(self) -> None:
        """Test case for show_chat

        Show Chat
        """
        pass

    def test_update_chat(self) -> None:
        """Test case for update_chat

        Update Chat
        """
        pass


if __name__ == '__main__':
    unittest.main()
