# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.roles_api import RolesApi


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RolesApi()

    def tearDown(self) -> None:
        pass

    def test_create_role(self) -> None:
        """Test case for create_role

        Create Role
        """
        pass

    def test_delete_role(self) -> None:
        """Test case for delete_role

        Delete Role
        """
        pass

    def test_list_role_users(self) -> None:
        """Test case for list_role_users

        List Role Users
        """
        pass

    def test_list_role_users_relationship(self) -> None:
        """Test case for list_role_users_relationship

        List Role Users Relationship
        """
        pass

    def test_list_roles(self) -> None:
        """Test case for list_roles

        List Roles
        """
        pass

    def test_role_options(self) -> None:
        """Test case for role_options

        Role Options
        """
        pass

    def test_role_users_options(self) -> None:
        """Test case for role_users_options

        Role Users Options
        """
        pass

    def test_role_users_relationships_options(self) -> None:
        """Test case for role_users_relationships_options

        Role Users Relationships Options
        """
        pass

    def test_roles_options(self) -> None:
        """Test case for roles_options

        Roles Options
        """
        pass

    def test_show_role(self) -> None:
        """Test case for show_role

        Show Role
        """
        pass

    def test_update_role(self) -> None:
        """Test case for update_role

        Update Role
        """
        pass


if __name__ == '__main__':
    unittest.main()
