# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.translations_api import TranslationsApi


class TestTranslationsApi(unittest.TestCase):
    """TranslationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TranslationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_translation(self) -> None:
        """Test case for create_translation

        Create Translation
        """
        pass

    def test_delete_translation(self) -> None:
        """Test case for delete_translation

        Delete Translation
        """
        pass

    def test_list_translations(self) -> None:
        """Test case for list_translations

        List Translations
        """
        pass

    def test_show_translation(self) -> None:
        """Test case for show_translation

        Show Translation
        """
        pass

    def test_translation_options(self) -> None:
        """Test case for translation_options

        Translation Options
        """
        pass

    def test_translations_options(self) -> None:
        """Test case for translations_options

        Translations Options
        """
        pass

    def test_update_translation(self) -> None:
        """Test case for update_translation

        Update Translation
        """
        pass


if __name__ == '__main__':
    unittest.main()
