# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData

class TestUpdateTenantRequestBodyData(unittest.TestCase):
    """UpdateTenantRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTenantRequestBodyData:
        """Test UpdateTenantRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTenantRequestBodyData`
        """
        model = UpdateTenantRequestBodyData()
        if include_optional:
            return UpdateTenantRequestBodyData(
                type = 'tenants',
                id = '',
                attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                    name = '', 
                    username = '', 
                    email = '01234', 
                    status = '', 
                    short_code = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    phone = '', 
                    address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                        county = '', 
                        country = '', 
                        city = '', 
                        postalcode = '', 
                        street = '', ), 
                    settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                        ad = smartytalent_client.models.ad.ad(), 
                        conversation = smartytalent_client.models.conversation.conversation(), 
                        report = smartytalent_client.models.report.report(), 
                        email = smartytalent_client.models.email.email(), 
                        language = '', 
                        calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                            enabled = True, 
                            twilio_subaccount_sid = '', 
                            twilio_phone_number = '', 
                            twilio_phone_sid = '', 
                            provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    plan = '0', 
                    active_languages = [
                        'ae-IO'
                        ], 
                    trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    timezone = '', 
                    logo_url = '', 
                    boe_phone = '', 
                    boe_email = '', )
            )
        else:
            return UpdateTenantRequestBodyData(
                type = 'tenants',
                id = '',
                attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                    name = '', 
                    username = '', 
                    email = '01234', 
                    status = '', 
                    short_code = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    phone = '', 
                    address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                        county = '', 
                        country = '', 
                        city = '', 
                        postalcode = '', 
                        street = '', ), 
                    settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                        ad = smartytalent_client.models.ad.ad(), 
                        conversation = smartytalent_client.models.conversation.conversation(), 
                        report = smartytalent_client.models.report.report(), 
                        email = smartytalent_client.models.email.email(), 
                        language = '', 
                        calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                            enabled = True, 
                            twilio_subaccount_sid = '', 
                            twilio_phone_number = '', 
                            twilio_phone_sid = '', 
                            provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    plan = '0', 
                    active_languages = [
                        'ae-IO'
                        ], 
                    trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    timezone = '', 
                    logo_url = '', 
                    boe_phone = '', 
                    boe_email = '', ),
        )
        """

    def testUpdateTenantRequestBodyData(self):
        """Test UpdateTenantRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
