# coding: utf-8

# flake8: noqa

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "ActionsApi",
    "AdsApi",
    "ApikeysApi",
    "AssessmentsApi",
    "BrowsersApi",
    "CallsApi",
    "CandidatesApi",
    "ChatsApi",
    "ConversationsApi",
    "EmailsApi",
    "FilesApi",
    "FindersApi",
    "FormsApi",
    "JobsApi",
    "LinksApi",
    "MeetingsApi",
    "NotesApi",
    "NotificationsApi",
    "OperationsApi",
    "PersonasApi",
    "ReportsApi",
    "RolesApi",
    "RunsApi",
    "TalentsApi",
    "TenantsApi",
    "TimelinesApi",
    "TranslationsApi",
    "TriggersApi",
    "UsersApi",
    "WebhooksApi",
    "WorkflowsApi",
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdAttributesSchema",
    "AdAttributesSchemaImagesInner",
    "AdRelationshipsJobDataSchema",
    "AdRelationshipsJobSchema",
    "AdRelationshipsSchema",
    "AdResourceSchema",
    "AdSchema",
    "AdsSchema",
    "ApikeyAttributesSchema",
    "ApikeyRelationshipsSchema",
    "ApikeyRelationshipsUserDataSchema",
    "ApikeyRelationshipsUserSchema",
    "ApikeyResourceSchema",
    "ApikeySchema",
    "ApikeysSchema",
    "AssessmentAttributesSchema",
    "AssessmentRelationshipsCandidateDataSchema",
    "AssessmentRelationshipsCandidateSchema",
    "AssessmentRelationshipsJobDataSchema",
    "AssessmentRelationshipsJobSchema",
    "AssessmentRelationshipsSchema",
    "AssessmentResourceSchema",
    "AssessmentSchema",
    "AssessmentsSchema",
    "BrowserAttributesSchema",
    "BrowserRelationshipsSchema",
    "BrowserRelationshipsTranslationsDataSchema",
    "BrowserRelationshipsTranslationsSchema",
    "BrowserResourceSchema",
    "BrowserSchema",
    "BrowsersSchema",
    "CallAttributesSchema",
    "CallRelationshipsSchema",
    "CallRelationshipsTranslationsDataSchema",
    "CallRelationshipsTranslationsSchema",
    "CallResourceSchema",
    "CallSchema",
    "CallsSchema",
    "CandidateAttributesSchema",
    "CandidateCriteriaSchema",
    "CandidateRelationshipsJobDataSchema",
    "CandidateRelationshipsJobSchema",
    "CandidateRelationshipsOperationsDataSchema",
    "CandidateRelationshipsOperationsSchema",
    "CandidateRelationshipsSchema",
    "CandidateRelationshipsTalentDataSchema",
    "CandidateRelationshipsTalentSchema",
    "CandidateRelationshipsTranslationsDataSchema",
    "CandidateRelationshipsTranslationsSchema",
    "CandidateResourceSchema",
    "CandidateSchema",
    "CandidatesSchema",
    "ChatAttributesSchema",
    "ChatRelationshipsSchema",
    "ChatRelationshipsTranslationsDataSchema",
    "ChatRelationshipsTranslationsSchema",
    "ChatResourceSchema",
    "ChatSchema",
    "ChatsSchema",
    "ConversationAttributesSchema",
    "ConversationRelationshipsCandidateDataSchema",
    "ConversationRelationshipsCandidateSchema",
    "ConversationRelationshipsSchema",
    "ConversationResourceSchema",
    "ConversationSchema",
    "ConversationsSchema",
    "CreateAdRequestBody",
    "CreateAdRequestBodyData",
    "CreateApikeyRequestBody",
    "CreateApikeyRequestBodyData",
    "CreateAssessmentRequestBody",
    "CreateAssessmentRequestBodyData",
    "CreateBrowserRequestBody",
    "CreateBrowserRequestBodyData",
    "CreateCallRequestBody",
    "CreateCallRequestBodyData",
    "CreateCandidateRequestBody",
    "CreateCandidateRequestBodyData",
    "CreateChatRequestBody",
    "CreateChatRequestBodyData",
    "CreateConversationRequestBody",
    "CreateConversationRequestBodyData",
    "CreateEmailRequestBody",
    "CreateEmailRequestBodyData",
    "CreateFileRequestBody",
    "CreateFileRequestBodyData",
    "CreateFinderRequestBody",
    "CreateFinderRequestBodyData",
    "CreateFormRequestBody",
    "CreateFormRequestBodyData",
    "CreateJobRequestBody",
    "CreateJobRequestBodyData",
    "CreateLinkRequestBody",
    "CreateLinkRequestBodyData",
    "CreateMeetingAiSessionRequestBody",
    "CreateMeetingAiSessionRequestBodyData",
    "CreateMeetingAttendeeRequestBody",
    "CreateMeetingAttendeeRequestBodyData",
    "CreateMeetingRequestBody",
    "CreateMeetingRequestBodyData",
    "CreateNoteRequestBody",
    "CreateNoteRequestBodyData",
    "CreateNotificationRequestBody",
    "CreateNotificationRequestBodyData",
    "CreateOperationRequestBody",
    "CreateOperationRequestBodyData",
    "CreatePersonaRequestBody",
    "CreatePersonaRequestBodyData",
    "CreateReportRequestBody",
    "CreateReportRequestBodyData",
    "CreateRoleRequestBody",
    "CreateRoleRequestBodyData",
    "CreateTalentRequestBody",
    "CreateTalentRequestBodyData",
    "CreateTenantRequestBody",
    "CreateTenantRequestBodyData",
    "CreateTenantUploadRequestBody",
    "CreateTenantUploadRequestBodyData",
    "CreateTenantUploadRequestBodyDataAttributes",
    "CreateTranslationRequestBody",
    "CreateTranslationRequestBodyData",
    "CreateUserRequestBody",
    "CreateUserRequestBodyData",
    "CreateUserUploadRequestBody",
    "CreateUserUploadRequestBodyData",
    "CreateUserUploadRequestBodyDataAttributes",
    "CreateWebhookRequestBody",
    "CreateWebhookRequestBodyData",
    "EmailAttributesSchema",
    "EmailRelationshipsCandidateDataSchema",
    "EmailRelationshipsCandidateSchema",
    "EmailRelationshipsOperationDataSchema",
    "EmailRelationshipsOperationSchema",
    "EmailRelationshipsReportDataSchema",
    "EmailRelationshipsReportSchema",
    "EmailRelationshipsSchema",
    "EmailRelationshipsTranslationsDataSchema",
    "EmailRelationshipsTranslationsSchema",
    "EmailResourceSchema",
    "EmailSchema",
    "EmailsSchema",
    "ErrorObjectSchema",
    "ErrorSchema",
    "FileAttributesSchema",
    "FileRelationshipsLinkDataSchema",
    "FileRelationshipsLinkSchema",
    "FileRelationshipsSchema",
    "FileResourceSchema",
    "FileSchema",
    "FilesSchema",
    "FinderAttributesSchema",
    "FinderRelationshipsCandidatesDataSchema",
    "FinderRelationshipsCandidatesSchema",
    "FinderRelationshipsJobsDataSchema",
    "FinderRelationshipsJobsSchema",
    "FinderRelationshipsSchema",
    "FinderRelationshipsTalentsDataSchema",
    "FinderRelationshipsTalentsSchema",
    "FinderRelationshipsUsersDataSchema",
    "FinderRelationshipsUsersSchema",
    "FinderResourceSchema",
    "FinderSchema",
    "FindersSchema",
    "FormAttributesSchema",
    "FormRelationshipsSchema",
    "FormRelationshipsTranslationsDataSchema",
    "FormRelationshipsTranslationsSchema",
    "FormResourceSchema",
    "FormSchema",
    "FormsSchema",
    "JobAttributesLocationItemSchema",
    "JobAttributesOrganizationAddressSchema",
    "JobAttributesOrganizationSchema",
    "JobAttributesSchema",
    "JobAttributesSettingsConversationCandidateInterviewSchema",
    "JobAttributesSettingsConversationEmailContactSchema",
    "JobAttributesSettingsConversationEmailDelaysSchema",
    "JobAttributesSettingsConversationEmailSchema",
    "JobAttributesSettingsConversationPersonaInterviewSchema",
    "JobAttributesSettingsConversationSchema",
    "JobAttributesSettingsCriteriasSchema",
    "JobAttributesSettingsOperationSchema",
    "JobAttributesSettingsPersonaSchema",
    "JobAttributesSettingsSchema",
    "JobAttributesSiteItemSchema",
    "JobCriteriaSchema",
    "JobRelationshipsCandidatesDataSchema",
    "JobRelationshipsCandidatesSchema",
    "JobRelationshipsConversationsDataSchema",
    "JobRelationshipsConversationsSchema",
    "JobRelationshipsOperationsDataSchema",
    "JobRelationshipsOperationsSchema",
    "JobRelationshipsPersonasDataSchema",
    "JobRelationshipsPersonasSchema",
    "JobRelationshipsSchema",
    "JobRelationshipsTranslationsDataSchema",
    "JobRelationshipsTranslationsSchema",
    "JobResourceSchema",
    "JobSchema",
    "JobsSchema",
    "LinkAttributesSchema",
    "LinkRelationshipsFileDataSchema",
    "LinkRelationshipsFileSchema",
    "LinkRelationshipsSchema",
    "LinkResourceSchema",
    "LinkSchema",
    "LinksSchema",
    "ListCandidateJobsRelationship",
    "ListCandidateTalentsRelationship",
    "ListJobCandidatesRelationship",
    "ListRoleUsersRelationship",
    "ListTalentCandidatesRelationship",
    "ListUserApikeysRelationship",
    "ListUserJobsRelationship",
    "ListUserRolesRelationship",
    "MeetingAiSessionAttributesSchema",
    "MeetingAiSessionAttributesSchemaRealtimeSession",
    "MeetingAiSessionResourceSchema",
    "MeetingAiSessionSchema",
    "MeetingAiSessionSettingsSchema",
    "MeetingAttendeeAttributesSchema",
    "MeetingAttendeeResourceSchema",
    "MeetingAttendeeResourceSchemaAllOfRelationships",
    "MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting",
    "MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData",
    "MeetingAttendeeResponseAttributesSchema",
    "MeetingAttendeeSchema",
    "MeetingAttributesSchema",
    "MeetingLobbyAttributesSchema",
    "MeetingLobbyResourceSchema",
    "MeetingLobbySchema",
    "MeetingRelationshipsParticipantsDataSchema",
    "MeetingRelationshipsParticipantsSchema",
    "MeetingRelationshipsSchema",
    "MeetingResourceSchema",
    "MeetingSchema",
    "MeetingTranscriptionAttributesSchema",
    "MeetingTranscriptionRequestBody",
    "MeetingTranscriptionRequestBodyData",
    "MeetingTranscriptionSchema",
    "MeetingTranscriptionSchemaData",
    "MeetingTranscriptionSettingsSchema",
    "MeetingsSchema",
    "NoteAttributesSchema",
    "NoteRelationshipsCandidateDataSchema",
    "NoteRelationshipsCandidateSchema",
    "NoteRelationshipsOperationDataSchema",
    "NoteRelationshipsOperationSchema",
    "NoteRelationshipsReportDataSchema",
    "NoteRelationshipsReportSchema",
    "NoteRelationshipsSchema",
    "NoteRelationshipsTranslationsDataSchema",
    "NoteRelationshipsTranslationsSchema",
    "NoteResourceSchema",
    "NoteSchema",
    "NotesSchema",
    "NotificationAttributesSchema",
    "NotificationRelationshipsSchema",
    "NotificationRelationshipsSchemaUsers",
    "NotificationRelationshipsSchemaUsersDataInner",
    "NotificationResourceSchema",
    "NotificationSchema",
    "NotificationsSchema",
    "OperationAttributesSchema",
    "OperationRelationshipsCandidateDataSchema",
    "OperationRelationshipsCandidateSchema",
    "OperationRelationshipsJobDataSchema",
    "OperationRelationshipsJobSchema",
    "OperationRelationshipsSchema",
    "OperationResourceSchema",
    "OperationSchema",
    "OperationsSchema",
    "PersonaAttributesSchema",
    "PersonaRelationshipsCandidatesDataSchema",
    "PersonaRelationshipsCandidatesSchema",
    "PersonaRelationshipsOperationsDataSchema",
    "PersonaRelationshipsOperationsSchema",
    "PersonaRelationshipsSchema",
    "PersonaRelationshipsTalentsDataSchema",
    "PersonaRelationshipsTalentsSchema",
    "PersonaRelationshipsTranslationsDataSchema",
    "PersonaRelationshipsTranslationsSchema",
    "PersonaResourceSchema",
    "PersonaSchema",
    "PersonasSchema",
    "PurchaseTenantPhoneNumberRequest",
    "PurchaseTenantPhoneNumberRequestData",
    "PurchaseTenantPhoneNumberRequestDataAttributes",
    "ReportAttributesSchema",
    "ReportRelationshipsSchema",
    "ReportRelationshipsTenantsDataSchema",
    "ReportRelationshipsTenantsSchema",
    "ReportResourceSchema",
    "ReportSchema",
    "ReportsSchema",
    "ResourceIdentifierSchema",
    "ResourceLinksSchema",
    "ResourceRelationshipsLinksSchema",
    "ResourceRelationshipsMetaSchema",
    "ResourceSchema",
    "ResourceTimestampsSchema",
    "ResourcesLinksSchema",
    "ResourcesMetaPageSchema",
    "ResourcesMetaSchema",
    "RoleAttributesSchema",
    "RoleRelationshipsPermissionsDataSchema",
    "RoleRelationshipsPermissionsSchema",
    "RoleRelationshipsSchema",
    "RoleRelationshipsUsersDataSchema",
    "RoleRelationshipsUsersSchema",
    "RoleResourceSchema",
    "RoleSchema",
    "RolesSchema",
    "TalentAlumniSchema",
    "TalentAttributesDesiredContractLengthSchema",
    "TalentAttributesDesiredEmploymentTypeSchema",
    "TalentAttributesDesiredRoleSchema",
    "TalentAttributesEmploymentTypeSchema",
    "TalentAttributesSchema",
    "TalentAttributesSocialLinkSchema",
    "TalentAvailabilityReceivedCriteriaSchema",
    "TalentReceivedCriteriaSchema",
    "TalentReferralSchema",
    "TalentReferralSchemaReferrer",
    "TalentRelationshipsCandidatesDataSchema",
    "TalentRelationshipsCandidatesSchema",
    "TalentRelationshipsFilesDataSchema",
    "TalentRelationshipsFilesSchema",
    "TalentRelationshipsOperationsDataSchema",
    "TalentRelationshipsOperationsSchema",
    "TalentRelationshipsSchema",
    "TalentRelationshipsTranslationsDataSchema",
    "TalentRelationshipsTranslationsSchema",
    "TalentResourceSchema",
    "TalentSchema",
    "TalentsSchema",
    "TenantAttributesAddressSchema",
    "TenantAttributesSchema",
    "TenantAttributesSettingsSchema",
    "TenantAttributesSettingsSchemaCalling",
    "TenantResourceSchema",
    "TenantSchema",
    "TenantUploadAttributesSchema",
    "TenantUploadResourceSchema",
    "TenantUploadSchema",
    "TenantsMetaPageSchema",
    "TenantsMetaSchema",
    "TenantsSchema",
    "TimelineAttributesSchema",
    "TimelineAttributesSchemaChangesValue",
    "TimelineAttributesSchemaSummaryValue",
    "TimelineAttributesSchemaSummaryValueUser",
    "TimelineAttributesSchemaTimestamps",
    "TimelineResourceSchema",
    "TimelineSchema",
    "TimelinesSchema",
    "TranslationAttributesSchema",
    "TranslationRelationshipsCandidateDataSchema",
    "TranslationRelationshipsCandidateSchema",
    "TranslationRelationshipsJobDataSchema",
    "TranslationRelationshipsJobSchema",
    "TranslationRelationshipsReportDataSchema",
    "TranslationRelationshipsReportSchema",
    "TranslationRelationshipsSchema",
    "TranslationRelationshipsTalentDataSchema",
    "TranslationRelationshipsTalentSchema",
    "TranslationResourceSchema",
    "TranslationSchema",
    "TranslationsSchema",
    "UpdateAdRequestBody",
    "UpdateAdRequestBodyData",
    "UpdateApikeyRequestBody",
    "UpdateApikeyRequestBodyData",
    "UpdateAssessmentRequestBody",
    "UpdateAssessmentRequestBodyData",
    "UpdateBrowserRequestBody",
    "UpdateBrowserRequestBodyData",
    "UpdateCallRequestBody",
    "UpdateCallRequestBodyData",
    "UpdateCandidateRequestBody",
    "UpdateCandidateRequestBodyData",
    "UpdateChatRequestBody",
    "UpdateChatRequestBodyData",
    "UpdateConversationRequestBody",
    "UpdateConversationRequestBodyData",
    "UpdateEmailRequestBody",
    "UpdateEmailRequestBodyData",
    "UpdateFileRequestBody",
    "UpdateFileRequestBodyData",
    "UpdateFinderRequestBody",
    "UpdateFinderRequestBodyData",
    "UpdateFormRequestBody",
    "UpdateFormRequestBodyData",
    "UpdateJobRequestBody",
    "UpdateJobRequestBodyData",
    "UpdateLinkRequestBody",
    "UpdateLinkRequestBodyData",
    "UpdateMeetingRequestBody",
    "UpdateMeetingRequestBodyData",
    "UpdateNoteRequestBody",
    "UpdateNoteRequestBodyData",
    "UpdateNotificationRequestBody",
    "UpdateNotificationRequestBodyData",
    "UpdateNotificationRequestBodyDataAttributes",
    "UpdateOperationRequestBody",
    "UpdateOperationRequestBodyData",
    "UpdatePersonaRequestBody",
    "UpdatePersonaRequestBodyData",
    "UpdateReportRequestBody",
    "UpdateReportRequestBodyData",
    "UpdateRoleRequestBody",
    "UpdateRoleRequestBodyData",
    "UpdateTalentRequestBody",
    "UpdateTalentRequestBodyData",
    "UpdateTenantRequestBody",
    "UpdateTenantRequestBodyData",
    "UpdateTranslationRequestBody",
    "UpdateTranslationRequestBodyData",
    "UpdateUserRequestBody",
    "UpdateUserRequestBodyData",
    "UpdateWebhookRequestBody",
    "UpdateWebhookRequestBodyData",
    "UserAttributesSchema",
    "UserHistoryEventSchema",
    "UserHistoryEventSchemaChallengeResponsesInner",
    "UserHistoryEventSchemaEventFeedback",
    "UserRelationshipsApikeysDataSchema",
    "UserRelationshipsApikeysSchema",
    "UserRelationshipsJobsDataSchema",
    "UserRelationshipsJobsSchema",
    "UserRelationshipsRoleDataSchema",
    "UserRelationshipsRoleSchema",
    "UserRelationshipsSchema",
    "UserResourceSchema",
    "UserSchema",
    "UserUploadAttributesSchema",
    "UserUploadResourceSchema",
    "UserUploadSchema",
    "UsersSchema",
    "WebhookAttributesSchema",
    "WebhookResourceSchema",
    "WebhookSchema",
    "WebhooksSchema",
]

# import apis into sdk package
from smartytalent_client.api.actions_api import ActionsApi as ActionsApi
from smartytalent_client.api.ads_api import AdsApi as AdsApi
from smartytalent_client.api.apikeys_api import ApikeysApi as ApikeysApi
from smartytalent_client.api.assessments_api import AssessmentsApi as AssessmentsApi
from smartytalent_client.api.browsers_api import BrowsersApi as BrowsersApi
from smartytalent_client.api.calls_api import CallsApi as CallsApi
from smartytalent_client.api.candidates_api import CandidatesApi as CandidatesApi
from smartytalent_client.api.chats_api import ChatsApi as ChatsApi
from smartytalent_client.api.conversations_api import ConversationsApi as ConversationsApi
from smartytalent_client.api.emails_api import EmailsApi as EmailsApi
from smartytalent_client.api.files_api import FilesApi as FilesApi
from smartytalent_client.api.finders_api import FindersApi as FindersApi
from smartytalent_client.api.forms_api import FormsApi as FormsApi
from smartytalent_client.api.jobs_api import JobsApi as JobsApi
from smartytalent_client.api.links_api import LinksApi as LinksApi
from smartytalent_client.api.meetings_api import MeetingsApi as MeetingsApi
from smartytalent_client.api.notes_api import NotesApi as NotesApi
from smartytalent_client.api.notifications_api import NotificationsApi as NotificationsApi
from smartytalent_client.api.operations_api import OperationsApi as OperationsApi
from smartytalent_client.api.personas_api import PersonasApi as PersonasApi
from smartytalent_client.api.reports_api import ReportsApi as ReportsApi
from smartytalent_client.api.roles_api import RolesApi as RolesApi
from smartytalent_client.api.runs_api import RunsApi as RunsApi
from smartytalent_client.api.talents_api import TalentsApi as TalentsApi
from smartytalent_client.api.tenants_api import TenantsApi as TenantsApi
from smartytalent_client.api.timelines_api import TimelinesApi as TimelinesApi
from smartytalent_client.api.translations_api import TranslationsApi as TranslationsApi
from smartytalent_client.api.triggers_api import TriggersApi as TriggersApi
from smartytalent_client.api.users_api import UsersApi as UsersApi
from smartytalent_client.api.webhooks_api import WebhooksApi as WebhooksApi
from smartytalent_client.api.workflows_api import WorkflowsApi as WorkflowsApi
from smartytalent_client.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from smartytalent_client.api_response import ApiResponse as ApiResponse
from smartytalent_client.api_client import ApiClient as ApiClient
from smartytalent_client.configuration import Configuration as Configuration
from smartytalent_client.exceptions import OpenApiException as OpenApiException
from smartytalent_client.exceptions import ApiTypeError as ApiTypeError
from smartytalent_client.exceptions import ApiValueError as ApiValueError
from smartytalent_client.exceptions import ApiKeyError as ApiKeyError
from smartytalent_client.exceptions import ApiAttributeError as ApiAttributeError
from smartytalent_client.exceptions import ApiException as ApiException

# import models into sdk package
from smartytalent_client.models.ad_attributes_schema import AdAttributesSchema as AdAttributesSchema
from smartytalent_client.models.ad_attributes_schema_images_inner import AdAttributesSchemaImagesInner as AdAttributesSchemaImagesInner
from smartytalent_client.models.ad_relationships_job_data_schema import AdRelationshipsJobDataSchema as AdRelationshipsJobDataSchema
from smartytalent_client.models.ad_relationships_job_schema import AdRelationshipsJobSchema as AdRelationshipsJobSchema
from smartytalent_client.models.ad_relationships_schema import AdRelationshipsSchema as AdRelationshipsSchema
from smartytalent_client.models.ad_resource_schema import AdResourceSchema as AdResourceSchema
from smartytalent_client.models.ad_schema import AdSchema as AdSchema
from smartytalent_client.models.ads_schema import AdsSchema as AdsSchema
from smartytalent_client.models.apikey_attributes_schema import ApikeyAttributesSchema as ApikeyAttributesSchema
from smartytalent_client.models.apikey_relationships_schema import ApikeyRelationshipsSchema as ApikeyRelationshipsSchema
from smartytalent_client.models.apikey_relationships_user_data_schema import ApikeyRelationshipsUserDataSchema as ApikeyRelationshipsUserDataSchema
from smartytalent_client.models.apikey_relationships_user_schema import ApikeyRelationshipsUserSchema as ApikeyRelationshipsUserSchema
from smartytalent_client.models.apikey_resource_schema import ApikeyResourceSchema as ApikeyResourceSchema
from smartytalent_client.models.apikey_schema import ApikeySchema as ApikeySchema
from smartytalent_client.models.apikeys_schema import ApikeysSchema as ApikeysSchema
from smartytalent_client.models.assessment_attributes_schema import AssessmentAttributesSchema as AssessmentAttributesSchema
from smartytalent_client.models.assessment_relationships_candidate_data_schema import AssessmentRelationshipsCandidateDataSchema as AssessmentRelationshipsCandidateDataSchema
from smartytalent_client.models.assessment_relationships_candidate_schema import AssessmentRelationshipsCandidateSchema as AssessmentRelationshipsCandidateSchema
from smartytalent_client.models.assessment_relationships_job_data_schema import AssessmentRelationshipsJobDataSchema as AssessmentRelationshipsJobDataSchema
from smartytalent_client.models.assessment_relationships_job_schema import AssessmentRelationshipsJobSchema as AssessmentRelationshipsJobSchema
from smartytalent_client.models.assessment_relationships_schema import AssessmentRelationshipsSchema as AssessmentRelationshipsSchema
from smartytalent_client.models.assessment_resource_schema import AssessmentResourceSchema as AssessmentResourceSchema
from smartytalent_client.models.assessment_schema import AssessmentSchema as AssessmentSchema
from smartytalent_client.models.assessments_schema import AssessmentsSchema as AssessmentsSchema
from smartytalent_client.models.browser_attributes_schema import BrowserAttributesSchema as BrowserAttributesSchema
from smartytalent_client.models.browser_relationships_schema import BrowserRelationshipsSchema as BrowserRelationshipsSchema
from smartytalent_client.models.browser_relationships_translations_data_schema import BrowserRelationshipsTranslationsDataSchema as BrowserRelationshipsTranslationsDataSchema
from smartytalent_client.models.browser_relationships_translations_schema import BrowserRelationshipsTranslationsSchema as BrowserRelationshipsTranslationsSchema
from smartytalent_client.models.browser_resource_schema import BrowserResourceSchema as BrowserResourceSchema
from smartytalent_client.models.browser_schema import BrowserSchema as BrowserSchema
from smartytalent_client.models.browsers_schema import BrowsersSchema as BrowsersSchema
from smartytalent_client.models.call_attributes_schema import CallAttributesSchema as CallAttributesSchema
from smartytalent_client.models.call_relationships_schema import CallRelationshipsSchema as CallRelationshipsSchema
from smartytalent_client.models.call_relationships_translations_data_schema import CallRelationshipsTranslationsDataSchema as CallRelationshipsTranslationsDataSchema
from smartytalent_client.models.call_relationships_translations_schema import CallRelationshipsTranslationsSchema as CallRelationshipsTranslationsSchema
from smartytalent_client.models.call_resource_schema import CallResourceSchema as CallResourceSchema
from smartytalent_client.models.call_schema import CallSchema as CallSchema
from smartytalent_client.models.calls_schema import CallsSchema as CallsSchema
from smartytalent_client.models.candidate_attributes_schema import CandidateAttributesSchema as CandidateAttributesSchema
from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema as CandidateCriteriaSchema
from smartytalent_client.models.candidate_relationships_job_data_schema import CandidateRelationshipsJobDataSchema as CandidateRelationshipsJobDataSchema
from smartytalent_client.models.candidate_relationships_job_schema import CandidateRelationshipsJobSchema as CandidateRelationshipsJobSchema
from smartytalent_client.models.candidate_relationships_operations_data_schema import CandidateRelationshipsOperationsDataSchema as CandidateRelationshipsOperationsDataSchema
from smartytalent_client.models.candidate_relationships_operations_schema import CandidateRelationshipsOperationsSchema as CandidateRelationshipsOperationsSchema
from smartytalent_client.models.candidate_relationships_schema import CandidateRelationshipsSchema as CandidateRelationshipsSchema
from smartytalent_client.models.candidate_relationships_talent_data_schema import CandidateRelationshipsTalentDataSchema as CandidateRelationshipsTalentDataSchema
from smartytalent_client.models.candidate_relationships_talent_schema import CandidateRelationshipsTalentSchema as CandidateRelationshipsTalentSchema
from smartytalent_client.models.candidate_relationships_translations_data_schema import CandidateRelationshipsTranslationsDataSchema as CandidateRelationshipsTranslationsDataSchema
from smartytalent_client.models.candidate_relationships_translations_schema import CandidateRelationshipsTranslationsSchema as CandidateRelationshipsTranslationsSchema
from smartytalent_client.models.candidate_resource_schema import CandidateResourceSchema as CandidateResourceSchema
from smartytalent_client.models.candidate_schema import CandidateSchema as CandidateSchema
from smartytalent_client.models.candidates_schema import CandidatesSchema as CandidatesSchema
from smartytalent_client.models.chat_attributes_schema import ChatAttributesSchema as ChatAttributesSchema
from smartytalent_client.models.chat_relationships_schema import ChatRelationshipsSchema as ChatRelationshipsSchema
from smartytalent_client.models.chat_relationships_translations_data_schema import ChatRelationshipsTranslationsDataSchema as ChatRelationshipsTranslationsDataSchema
from smartytalent_client.models.chat_relationships_translations_schema import ChatRelationshipsTranslationsSchema as ChatRelationshipsTranslationsSchema
from smartytalent_client.models.chat_resource_schema import ChatResourceSchema as ChatResourceSchema
from smartytalent_client.models.chat_schema import ChatSchema as ChatSchema
from smartytalent_client.models.chats_schema import ChatsSchema as ChatsSchema
from smartytalent_client.models.conversation_attributes_schema import ConversationAttributesSchema as ConversationAttributesSchema
from smartytalent_client.models.conversation_relationships_candidate_data_schema import ConversationRelationshipsCandidateDataSchema as ConversationRelationshipsCandidateDataSchema
from smartytalent_client.models.conversation_relationships_candidate_schema import ConversationRelationshipsCandidateSchema as ConversationRelationshipsCandidateSchema
from smartytalent_client.models.conversation_relationships_schema import ConversationRelationshipsSchema as ConversationRelationshipsSchema
from smartytalent_client.models.conversation_resource_schema import ConversationResourceSchema as ConversationResourceSchema
from smartytalent_client.models.conversation_schema import ConversationSchema as ConversationSchema
from smartytalent_client.models.conversations_schema import ConversationsSchema as ConversationsSchema
from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody as CreateAdRequestBody
from smartytalent_client.models.create_ad_request_body_data import CreateAdRequestBodyData as CreateAdRequestBodyData
from smartytalent_client.models.create_apikey_request_body import CreateApikeyRequestBody as CreateApikeyRequestBody
from smartytalent_client.models.create_apikey_request_body_data import CreateApikeyRequestBodyData as CreateApikeyRequestBodyData
from smartytalent_client.models.create_assessment_request_body import CreateAssessmentRequestBody as CreateAssessmentRequestBody
from smartytalent_client.models.create_assessment_request_body_data import CreateAssessmentRequestBodyData as CreateAssessmentRequestBodyData
from smartytalent_client.models.create_browser_request_body import CreateBrowserRequestBody as CreateBrowserRequestBody
from smartytalent_client.models.create_browser_request_body_data import CreateBrowserRequestBodyData as CreateBrowserRequestBodyData
from smartytalent_client.models.create_call_request_body import CreateCallRequestBody as CreateCallRequestBody
from smartytalent_client.models.create_call_request_body_data import CreateCallRequestBodyData as CreateCallRequestBodyData
from smartytalent_client.models.create_candidate_request_body import CreateCandidateRequestBody as CreateCandidateRequestBody
from smartytalent_client.models.create_candidate_request_body_data import CreateCandidateRequestBodyData as CreateCandidateRequestBodyData
from smartytalent_client.models.create_chat_request_body import CreateChatRequestBody as CreateChatRequestBody
from smartytalent_client.models.create_chat_request_body_data import CreateChatRequestBodyData as CreateChatRequestBodyData
from smartytalent_client.models.create_conversation_request_body import CreateConversationRequestBody as CreateConversationRequestBody
from smartytalent_client.models.create_conversation_request_body_data import CreateConversationRequestBodyData as CreateConversationRequestBodyData
from smartytalent_client.models.create_email_request_body import CreateEmailRequestBody as CreateEmailRequestBody
from smartytalent_client.models.create_email_request_body_data import CreateEmailRequestBodyData as CreateEmailRequestBodyData
from smartytalent_client.models.create_file_request_body import CreateFileRequestBody as CreateFileRequestBody
from smartytalent_client.models.create_file_request_body_data import CreateFileRequestBodyData as CreateFileRequestBodyData
from smartytalent_client.models.create_finder_request_body import CreateFinderRequestBody as CreateFinderRequestBody
from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData as CreateFinderRequestBodyData
from smartytalent_client.models.create_form_request_body import CreateFormRequestBody as CreateFormRequestBody
from smartytalent_client.models.create_form_request_body_data import CreateFormRequestBodyData as CreateFormRequestBodyData
from smartytalent_client.models.create_job_request_body import CreateJobRequestBody as CreateJobRequestBody
from smartytalent_client.models.create_job_request_body_data import CreateJobRequestBodyData as CreateJobRequestBodyData
from smartytalent_client.models.create_link_request_body import CreateLinkRequestBody as CreateLinkRequestBody
from smartytalent_client.models.create_link_request_body_data import CreateLinkRequestBodyData as CreateLinkRequestBodyData
from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody as CreateMeetingAiSessionRequestBody
from smartytalent_client.models.create_meeting_ai_session_request_body_data import CreateMeetingAiSessionRequestBodyData as CreateMeetingAiSessionRequestBodyData
from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody as CreateMeetingAttendeeRequestBody
from smartytalent_client.models.create_meeting_attendee_request_body_data import CreateMeetingAttendeeRequestBodyData as CreateMeetingAttendeeRequestBodyData
from smartytalent_client.models.create_meeting_request_body import CreateMeetingRequestBody as CreateMeetingRequestBody
from smartytalent_client.models.create_meeting_request_body_data import CreateMeetingRequestBodyData as CreateMeetingRequestBodyData
from smartytalent_client.models.create_note_request_body import CreateNoteRequestBody as CreateNoteRequestBody
from smartytalent_client.models.create_note_request_body_data import CreateNoteRequestBodyData as CreateNoteRequestBodyData
from smartytalent_client.models.create_notification_request_body import CreateNotificationRequestBody as CreateNotificationRequestBody
from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData as CreateNotificationRequestBodyData
from smartytalent_client.models.create_operation_request_body import CreateOperationRequestBody as CreateOperationRequestBody
from smartytalent_client.models.create_operation_request_body_data import CreateOperationRequestBodyData as CreateOperationRequestBodyData
from smartytalent_client.models.create_persona_request_body import CreatePersonaRequestBody as CreatePersonaRequestBody
from smartytalent_client.models.create_persona_request_body_data import CreatePersonaRequestBodyData as CreatePersonaRequestBodyData
from smartytalent_client.models.create_report_request_body import CreateReportRequestBody as CreateReportRequestBody
from smartytalent_client.models.create_report_request_body_data import CreateReportRequestBodyData as CreateReportRequestBodyData
from smartytalent_client.models.create_role_request_body import CreateRoleRequestBody as CreateRoleRequestBody
from smartytalent_client.models.create_role_request_body_data import CreateRoleRequestBodyData as CreateRoleRequestBodyData
from smartytalent_client.models.create_talent_request_body import CreateTalentRequestBody as CreateTalentRequestBody
from smartytalent_client.models.create_talent_request_body_data import CreateTalentRequestBodyData as CreateTalentRequestBodyData
from smartytalent_client.models.create_tenant_request_body import CreateTenantRequestBody as CreateTenantRequestBody
from smartytalent_client.models.create_tenant_request_body_data import CreateTenantRequestBodyData as CreateTenantRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body import CreateTenantUploadRequestBody as CreateTenantUploadRequestBody
from smartytalent_client.models.create_tenant_upload_request_body_data import CreateTenantUploadRequestBodyData as CreateTenantUploadRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body_data_attributes import CreateTenantUploadRequestBodyDataAttributes as CreateTenantUploadRequestBodyDataAttributes
from smartytalent_client.models.create_translation_request_body import CreateTranslationRequestBody as CreateTranslationRequestBody
from smartytalent_client.models.create_translation_request_body_data import CreateTranslationRequestBodyData as CreateTranslationRequestBodyData
from smartytalent_client.models.create_user_request_body import CreateUserRequestBody as CreateUserRequestBody
from smartytalent_client.models.create_user_request_body_data import CreateUserRequestBodyData as CreateUserRequestBodyData
from smartytalent_client.models.create_user_upload_request_body import CreateUserUploadRequestBody as CreateUserUploadRequestBody
from smartytalent_client.models.create_user_upload_request_body_data import CreateUserUploadRequestBodyData as CreateUserUploadRequestBodyData
from smartytalent_client.models.create_user_upload_request_body_data_attributes import CreateUserUploadRequestBodyDataAttributes as CreateUserUploadRequestBodyDataAttributes
from smartytalent_client.models.create_webhook_request_body import CreateWebhookRequestBody as CreateWebhookRequestBody
from smartytalent_client.models.create_webhook_request_body_data import CreateWebhookRequestBodyData as CreateWebhookRequestBodyData
from smartytalent_client.models.email_attributes_schema import EmailAttributesSchema as EmailAttributesSchema
from smartytalent_client.models.email_relationships_candidate_data_schema import EmailRelationshipsCandidateDataSchema as EmailRelationshipsCandidateDataSchema
from smartytalent_client.models.email_relationships_candidate_schema import EmailRelationshipsCandidateSchema as EmailRelationshipsCandidateSchema
from smartytalent_client.models.email_relationships_operation_data_schema import EmailRelationshipsOperationDataSchema as EmailRelationshipsOperationDataSchema
from smartytalent_client.models.email_relationships_operation_schema import EmailRelationshipsOperationSchema as EmailRelationshipsOperationSchema
from smartytalent_client.models.email_relationships_report_data_schema import EmailRelationshipsReportDataSchema as EmailRelationshipsReportDataSchema
from smartytalent_client.models.email_relationships_report_schema import EmailRelationshipsReportSchema as EmailRelationshipsReportSchema
from smartytalent_client.models.email_relationships_schema import EmailRelationshipsSchema as EmailRelationshipsSchema
from smartytalent_client.models.email_relationships_translations_data_schema import EmailRelationshipsTranslationsDataSchema as EmailRelationshipsTranslationsDataSchema
from smartytalent_client.models.email_relationships_translations_schema import EmailRelationshipsTranslationsSchema as EmailRelationshipsTranslationsSchema
from smartytalent_client.models.email_resource_schema import EmailResourceSchema as EmailResourceSchema
from smartytalent_client.models.email_schema import EmailSchema as EmailSchema
from smartytalent_client.models.emails_schema import EmailsSchema as EmailsSchema
from smartytalent_client.models.error_object_schema import ErrorObjectSchema as ErrorObjectSchema
from smartytalent_client.models.error_schema import ErrorSchema as ErrorSchema
from smartytalent_client.models.file_attributes_schema import FileAttributesSchema as FileAttributesSchema
from smartytalent_client.models.file_relationships_link_data_schema import FileRelationshipsLinkDataSchema as FileRelationshipsLinkDataSchema
from smartytalent_client.models.file_relationships_link_schema import FileRelationshipsLinkSchema as FileRelationshipsLinkSchema
from smartytalent_client.models.file_relationships_schema import FileRelationshipsSchema as FileRelationshipsSchema
from smartytalent_client.models.file_resource_schema import FileResourceSchema as FileResourceSchema
from smartytalent_client.models.file_schema import FileSchema as FileSchema
from smartytalent_client.models.files_schema import FilesSchema as FilesSchema
from smartytalent_client.models.finder_attributes_schema import FinderAttributesSchema as FinderAttributesSchema
from smartytalent_client.models.finder_relationships_candidates_data_schema import FinderRelationshipsCandidatesDataSchema as FinderRelationshipsCandidatesDataSchema
from smartytalent_client.models.finder_relationships_candidates_schema import FinderRelationshipsCandidatesSchema as FinderRelationshipsCandidatesSchema
from smartytalent_client.models.finder_relationships_jobs_data_schema import FinderRelationshipsJobsDataSchema as FinderRelationshipsJobsDataSchema
from smartytalent_client.models.finder_relationships_jobs_schema import FinderRelationshipsJobsSchema as FinderRelationshipsJobsSchema
from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema as FinderRelationshipsSchema
from smartytalent_client.models.finder_relationships_talents_data_schema import FinderRelationshipsTalentsDataSchema as FinderRelationshipsTalentsDataSchema
from smartytalent_client.models.finder_relationships_talents_schema import FinderRelationshipsTalentsSchema as FinderRelationshipsTalentsSchema
from smartytalent_client.models.finder_relationships_users_data_schema import FinderRelationshipsUsersDataSchema as FinderRelationshipsUsersDataSchema
from smartytalent_client.models.finder_relationships_users_schema import FinderRelationshipsUsersSchema as FinderRelationshipsUsersSchema
from smartytalent_client.models.finder_resource_schema import FinderResourceSchema as FinderResourceSchema
from smartytalent_client.models.finder_schema import FinderSchema as FinderSchema
from smartytalent_client.models.finders_schema import FindersSchema as FindersSchema
from smartytalent_client.models.form_attributes_schema import FormAttributesSchema as FormAttributesSchema
from smartytalent_client.models.form_relationships_schema import FormRelationshipsSchema as FormRelationshipsSchema
from smartytalent_client.models.form_relationships_translations_data_schema import FormRelationshipsTranslationsDataSchema as FormRelationshipsTranslationsDataSchema
from smartytalent_client.models.form_relationships_translations_schema import FormRelationshipsTranslationsSchema as FormRelationshipsTranslationsSchema
from smartytalent_client.models.form_resource_schema import FormResourceSchema as FormResourceSchema
from smartytalent_client.models.form_schema import FormSchema as FormSchema
from smartytalent_client.models.forms_schema import FormsSchema as FormsSchema
from smartytalent_client.models.job_attributes_location_item_schema import JobAttributesLocationItemSchema as JobAttributesLocationItemSchema
from smartytalent_client.models.job_attributes_organization_address_schema import JobAttributesOrganizationAddressSchema as JobAttributesOrganizationAddressSchema
from smartytalent_client.models.job_attributes_organization_schema import JobAttributesOrganizationSchema as JobAttributesOrganizationSchema
from smartytalent_client.models.job_attributes_schema import JobAttributesSchema as JobAttributesSchema
from smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema import JobAttributesSettingsConversationCandidateInterviewSchema as JobAttributesSettingsConversationCandidateInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema import JobAttributesSettingsConversationEmailContactSchema as JobAttributesSettingsConversationEmailContactSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema import JobAttributesSettingsConversationEmailDelaysSchema as JobAttributesSettingsConversationEmailDelaysSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_schema import JobAttributesSettingsConversationEmailSchema as JobAttributesSettingsConversationEmailSchema
from smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema import JobAttributesSettingsConversationPersonaInterviewSchema as JobAttributesSettingsConversationPersonaInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema as JobAttributesSettingsConversationSchema
from smartytalent_client.models.job_attributes_settings_criterias_schema import JobAttributesSettingsCriteriasSchema as JobAttributesSettingsCriteriasSchema
from smartytalent_client.models.job_attributes_settings_operation_schema import JobAttributesSettingsOperationSchema as JobAttributesSettingsOperationSchema
from smartytalent_client.models.job_attributes_settings_persona_schema import JobAttributesSettingsPersonaSchema as JobAttributesSettingsPersonaSchema
from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema as JobAttributesSettingsSchema
from smartytalent_client.models.job_attributes_site_item_schema import JobAttributesSiteItemSchema as JobAttributesSiteItemSchema
from smartytalent_client.models.job_criteria_schema import JobCriteriaSchema as JobCriteriaSchema
from smartytalent_client.models.job_relationships_candidates_data_schema import JobRelationshipsCandidatesDataSchema as JobRelationshipsCandidatesDataSchema
from smartytalent_client.models.job_relationships_candidates_schema import JobRelationshipsCandidatesSchema as JobRelationshipsCandidatesSchema
from smartytalent_client.models.job_relationships_conversations_data_schema import JobRelationshipsConversationsDataSchema as JobRelationshipsConversationsDataSchema
from smartytalent_client.models.job_relationships_conversations_schema import JobRelationshipsConversationsSchema as JobRelationshipsConversationsSchema
from smartytalent_client.models.job_relationships_operations_data_schema import JobRelationshipsOperationsDataSchema as JobRelationshipsOperationsDataSchema
from smartytalent_client.models.job_relationships_operations_schema import JobRelationshipsOperationsSchema as JobRelationshipsOperationsSchema
from smartytalent_client.models.job_relationships_personas_data_schema import JobRelationshipsPersonasDataSchema as JobRelationshipsPersonasDataSchema
from smartytalent_client.models.job_relationships_personas_schema import JobRelationshipsPersonasSchema as JobRelationshipsPersonasSchema
from smartytalent_client.models.job_relationships_schema import JobRelationshipsSchema as JobRelationshipsSchema
from smartytalent_client.models.job_relationships_translations_data_schema import JobRelationshipsTranslationsDataSchema as JobRelationshipsTranslationsDataSchema
from smartytalent_client.models.job_relationships_translations_schema import JobRelationshipsTranslationsSchema as JobRelationshipsTranslationsSchema
from smartytalent_client.models.job_resource_schema import JobResourceSchema as JobResourceSchema
from smartytalent_client.models.job_schema import JobSchema as JobSchema
from smartytalent_client.models.jobs_schema import JobsSchema as JobsSchema
from smartytalent_client.models.link_attributes_schema import LinkAttributesSchema as LinkAttributesSchema
from smartytalent_client.models.link_relationships_file_data_schema import LinkRelationshipsFileDataSchema as LinkRelationshipsFileDataSchema
from smartytalent_client.models.link_relationships_file_schema import LinkRelationshipsFileSchema as LinkRelationshipsFileSchema
from smartytalent_client.models.link_relationships_schema import LinkRelationshipsSchema as LinkRelationshipsSchema
from smartytalent_client.models.link_resource_schema import LinkResourceSchema as LinkResourceSchema
from smartytalent_client.models.link_schema import LinkSchema as LinkSchema
from smartytalent_client.models.links_schema import LinksSchema as LinksSchema
from smartytalent_client.models.list_candidate_jobs_relationship import ListCandidateJobsRelationship as ListCandidateJobsRelationship
from smartytalent_client.models.list_candidate_talents_relationship import ListCandidateTalentsRelationship as ListCandidateTalentsRelationship
from smartytalent_client.models.list_job_candidates_relationship import ListJobCandidatesRelationship as ListJobCandidatesRelationship
from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship as ListRoleUsersRelationship
from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship as ListTalentCandidatesRelationship
from smartytalent_client.models.list_user_apikeys_relationship import ListUserApikeysRelationship as ListUserApikeysRelationship
from smartytalent_client.models.list_user_jobs_relationship import ListUserJobsRelationship as ListUserJobsRelationship
from smartytalent_client.models.list_user_roles_relationship import ListUserRolesRelationship as ListUserRolesRelationship
from smartytalent_client.models.meeting_ai_session_attributes_schema import MeetingAiSessionAttributesSchema as MeetingAiSessionAttributesSchema
from smartytalent_client.models.meeting_ai_session_attributes_schema_realtime_session import MeetingAiSessionAttributesSchemaRealtimeSession as MeetingAiSessionAttributesSchemaRealtimeSession
from smartytalent_client.models.meeting_ai_session_resource_schema import MeetingAiSessionResourceSchema as MeetingAiSessionResourceSchema
from smartytalent_client.models.meeting_ai_session_schema import MeetingAiSessionSchema as MeetingAiSessionSchema
from smartytalent_client.models.meeting_ai_session_settings_schema import MeetingAiSessionSettingsSchema as MeetingAiSessionSettingsSchema
from smartytalent_client.models.meeting_attendee_attributes_schema import MeetingAttendeeAttributesSchema as MeetingAttendeeAttributesSchema
from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema as MeetingAttendeeResourceSchema
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships import MeetingAttendeeResourceSchemaAllOfRelationships as MeetingAttendeeResourceSchemaAllOfRelationships
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting import MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting as MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data import MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData as MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData
from smartytalent_client.models.meeting_attendee_response_attributes_schema import MeetingAttendeeResponseAttributesSchema as MeetingAttendeeResponseAttributesSchema
from smartytalent_client.models.meeting_attendee_schema import MeetingAttendeeSchema as MeetingAttendeeSchema
from smartytalent_client.models.meeting_attributes_schema import MeetingAttributesSchema as MeetingAttributesSchema
from smartytalent_client.models.meeting_lobby_attributes_schema import MeetingLobbyAttributesSchema as MeetingLobbyAttributesSchema
from smartytalent_client.models.meeting_lobby_resource_schema import MeetingLobbyResourceSchema as MeetingLobbyResourceSchema
from smartytalent_client.models.meeting_lobby_schema import MeetingLobbySchema as MeetingLobbySchema
from smartytalent_client.models.meeting_relationships_participants_data_schema import MeetingRelationshipsParticipantsDataSchema as MeetingRelationshipsParticipantsDataSchema
from smartytalent_client.models.meeting_relationships_participants_schema import MeetingRelationshipsParticipantsSchema as MeetingRelationshipsParticipantsSchema
from smartytalent_client.models.meeting_relationships_schema import MeetingRelationshipsSchema as MeetingRelationshipsSchema
from smartytalent_client.models.meeting_resource_schema import MeetingResourceSchema as MeetingResourceSchema
from smartytalent_client.models.meeting_schema import MeetingSchema as MeetingSchema
from smartytalent_client.models.meeting_transcription_attributes_schema import MeetingTranscriptionAttributesSchema as MeetingTranscriptionAttributesSchema
from smartytalent_client.models.meeting_transcription_request_body import MeetingTranscriptionRequestBody as MeetingTranscriptionRequestBody
from smartytalent_client.models.meeting_transcription_request_body_data import MeetingTranscriptionRequestBodyData as MeetingTranscriptionRequestBodyData
from smartytalent_client.models.meeting_transcription_schema import MeetingTranscriptionSchema as MeetingTranscriptionSchema
from smartytalent_client.models.meeting_transcription_schema_data import MeetingTranscriptionSchemaData as MeetingTranscriptionSchemaData
from smartytalent_client.models.meeting_transcription_settings_schema import MeetingTranscriptionSettingsSchema as MeetingTranscriptionSettingsSchema
from smartytalent_client.models.meetings_schema import MeetingsSchema as MeetingsSchema
from smartytalent_client.models.note_attributes_schema import NoteAttributesSchema as NoteAttributesSchema
from smartytalent_client.models.note_relationships_candidate_data_schema import NoteRelationshipsCandidateDataSchema as NoteRelationshipsCandidateDataSchema
from smartytalent_client.models.note_relationships_candidate_schema import NoteRelationshipsCandidateSchema as NoteRelationshipsCandidateSchema
from smartytalent_client.models.note_relationships_operation_data_schema import NoteRelationshipsOperationDataSchema as NoteRelationshipsOperationDataSchema
from smartytalent_client.models.note_relationships_operation_schema import NoteRelationshipsOperationSchema as NoteRelationshipsOperationSchema
from smartytalent_client.models.note_relationships_report_data_schema import NoteRelationshipsReportDataSchema as NoteRelationshipsReportDataSchema
from smartytalent_client.models.note_relationships_report_schema import NoteRelationshipsReportSchema as NoteRelationshipsReportSchema
from smartytalent_client.models.note_relationships_schema import NoteRelationshipsSchema as NoteRelationshipsSchema
from smartytalent_client.models.note_relationships_translations_data_schema import NoteRelationshipsTranslationsDataSchema as NoteRelationshipsTranslationsDataSchema
from smartytalent_client.models.note_relationships_translations_schema import NoteRelationshipsTranslationsSchema as NoteRelationshipsTranslationsSchema
from smartytalent_client.models.note_resource_schema import NoteResourceSchema as NoteResourceSchema
from smartytalent_client.models.note_schema import NoteSchema as NoteSchema
from smartytalent_client.models.notes_schema import NotesSchema as NotesSchema
from smartytalent_client.models.notification_attributes_schema import NotificationAttributesSchema as NotificationAttributesSchema
from smartytalent_client.models.notification_relationships_schema import NotificationRelationshipsSchema as NotificationRelationshipsSchema
from smartytalent_client.models.notification_relationships_schema_users import NotificationRelationshipsSchemaUsers as NotificationRelationshipsSchemaUsers
from smartytalent_client.models.notification_relationships_schema_users_data_inner import NotificationRelationshipsSchemaUsersDataInner as NotificationRelationshipsSchemaUsersDataInner
from smartytalent_client.models.notification_resource_schema import NotificationResourceSchema as NotificationResourceSchema
from smartytalent_client.models.notification_schema import NotificationSchema as NotificationSchema
from smartytalent_client.models.notifications_schema import NotificationsSchema as NotificationsSchema
from smartytalent_client.models.operation_attributes_schema import OperationAttributesSchema as OperationAttributesSchema
from smartytalent_client.models.operation_relationships_candidate_data_schema import OperationRelationshipsCandidateDataSchema as OperationRelationshipsCandidateDataSchema
from smartytalent_client.models.operation_relationships_candidate_schema import OperationRelationshipsCandidateSchema as OperationRelationshipsCandidateSchema
from smartytalent_client.models.operation_relationships_job_data_schema import OperationRelationshipsJobDataSchema as OperationRelationshipsJobDataSchema
from smartytalent_client.models.operation_relationships_job_schema import OperationRelationshipsJobSchema as OperationRelationshipsJobSchema
from smartytalent_client.models.operation_relationships_schema import OperationRelationshipsSchema as OperationRelationshipsSchema
from smartytalent_client.models.operation_resource_schema import OperationResourceSchema as OperationResourceSchema
from smartytalent_client.models.operation_schema import OperationSchema as OperationSchema
from smartytalent_client.models.operations_schema import OperationsSchema as OperationsSchema
from smartytalent_client.models.persona_attributes_schema import PersonaAttributesSchema as PersonaAttributesSchema
from smartytalent_client.models.persona_relationships_candidates_data_schema import PersonaRelationshipsCandidatesDataSchema as PersonaRelationshipsCandidatesDataSchema
from smartytalent_client.models.persona_relationships_candidates_schema import PersonaRelationshipsCandidatesSchema as PersonaRelationshipsCandidatesSchema
from smartytalent_client.models.persona_relationships_operations_data_schema import PersonaRelationshipsOperationsDataSchema as PersonaRelationshipsOperationsDataSchema
from smartytalent_client.models.persona_relationships_operations_schema import PersonaRelationshipsOperationsSchema as PersonaRelationshipsOperationsSchema
from smartytalent_client.models.persona_relationships_schema import PersonaRelationshipsSchema as PersonaRelationshipsSchema
from smartytalent_client.models.persona_relationships_talents_data_schema import PersonaRelationshipsTalentsDataSchema as PersonaRelationshipsTalentsDataSchema
from smartytalent_client.models.persona_relationships_talents_schema import PersonaRelationshipsTalentsSchema as PersonaRelationshipsTalentsSchema
from smartytalent_client.models.persona_relationships_translations_data_schema import PersonaRelationshipsTranslationsDataSchema as PersonaRelationshipsTranslationsDataSchema
from smartytalent_client.models.persona_relationships_translations_schema import PersonaRelationshipsTranslationsSchema as PersonaRelationshipsTranslationsSchema
from smartytalent_client.models.persona_resource_schema import PersonaResourceSchema as PersonaResourceSchema
from smartytalent_client.models.persona_schema import PersonaSchema as PersonaSchema
from smartytalent_client.models.personas_schema import PersonasSchema as PersonasSchema
from smartytalent_client.models.purchase_tenant_phone_number_request import PurchaseTenantPhoneNumberRequest as PurchaseTenantPhoneNumberRequest
from smartytalent_client.models.purchase_tenant_phone_number_request_data import PurchaseTenantPhoneNumberRequestData as PurchaseTenantPhoneNumberRequestData
from smartytalent_client.models.purchase_tenant_phone_number_request_data_attributes import PurchaseTenantPhoneNumberRequestDataAttributes as PurchaseTenantPhoneNumberRequestDataAttributes
from smartytalent_client.models.report_attributes_schema import ReportAttributesSchema as ReportAttributesSchema
from smartytalent_client.models.report_relationships_schema import ReportRelationshipsSchema as ReportRelationshipsSchema
from smartytalent_client.models.report_relationships_tenants_data_schema import ReportRelationshipsTenantsDataSchema as ReportRelationshipsTenantsDataSchema
from smartytalent_client.models.report_relationships_tenants_schema import ReportRelationshipsTenantsSchema as ReportRelationshipsTenantsSchema
from smartytalent_client.models.report_resource_schema import ReportResourceSchema as ReportResourceSchema
from smartytalent_client.models.report_schema import ReportSchema as ReportSchema
from smartytalent_client.models.reports_schema import ReportsSchema as ReportsSchema
from smartytalent_client.models.resource_identifier_schema import ResourceIdentifierSchema as ResourceIdentifierSchema
from smartytalent_client.models.resource_links_schema import ResourceLinksSchema as ResourceLinksSchema
from smartytalent_client.models.resource_relationships_links_schema import ResourceRelationshipsLinksSchema as ResourceRelationshipsLinksSchema
from smartytalent_client.models.resource_relationships_meta_schema import ResourceRelationshipsMetaSchema as ResourceRelationshipsMetaSchema
from smartytalent_client.models.resource_schema import ResourceSchema as ResourceSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema as ResourceTimestampsSchema
from smartytalent_client.models.resources_links_schema import ResourcesLinksSchema as ResourcesLinksSchema
from smartytalent_client.models.resources_meta_page_schema import ResourcesMetaPageSchema as ResourcesMetaPageSchema
from smartytalent_client.models.resources_meta_schema import ResourcesMetaSchema as ResourcesMetaSchema
from smartytalent_client.models.role_attributes_schema import RoleAttributesSchema as RoleAttributesSchema
from smartytalent_client.models.role_relationships_permissions_data_schema import RoleRelationshipsPermissionsDataSchema as RoleRelationshipsPermissionsDataSchema
from smartytalent_client.models.role_relationships_permissions_schema import RoleRelationshipsPermissionsSchema as RoleRelationshipsPermissionsSchema
from smartytalent_client.models.role_relationships_schema import RoleRelationshipsSchema as RoleRelationshipsSchema
from smartytalent_client.models.role_relationships_users_data_schema import RoleRelationshipsUsersDataSchema as RoleRelationshipsUsersDataSchema
from smartytalent_client.models.role_relationships_users_schema import RoleRelationshipsUsersSchema as RoleRelationshipsUsersSchema
from smartytalent_client.models.role_resource_schema import RoleResourceSchema as RoleResourceSchema
from smartytalent_client.models.role_schema import RoleSchema as RoleSchema
from smartytalent_client.models.roles_schema import RolesSchema as RolesSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema as TalentAlumniSchema
from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema as TalentAttributesDesiredContractLengthSchema
from smartytalent_client.models.talent_attributes_desired_employment_type_schema import TalentAttributesDesiredEmploymentTypeSchema as TalentAttributesDesiredEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_desired_role_schema import TalentAttributesDesiredRoleSchema as TalentAttributesDesiredRoleSchema
from smartytalent_client.models.talent_attributes_employment_type_schema import TalentAttributesEmploymentTypeSchema as TalentAttributesEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema as TalentAttributesSchema
from smartytalent_client.models.talent_attributes_social_link_schema import TalentAttributesSocialLinkSchema as TalentAttributesSocialLinkSchema
from smartytalent_client.models.talent_availability_received_criteria_schema import TalentAvailabilityReceivedCriteriaSchema as TalentAvailabilityReceivedCriteriaSchema
from smartytalent_client.models.talent_received_criteria_schema import TalentReceivedCriteriaSchema as TalentReceivedCriteriaSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema as TalentReferralSchema
from smartytalent_client.models.talent_referral_schema_referrer import TalentReferralSchemaReferrer as TalentReferralSchemaReferrer
from smartytalent_client.models.talent_relationships_candidates_data_schema import TalentRelationshipsCandidatesDataSchema as TalentRelationshipsCandidatesDataSchema
from smartytalent_client.models.talent_relationships_candidates_schema import TalentRelationshipsCandidatesSchema as TalentRelationshipsCandidatesSchema
from smartytalent_client.models.talent_relationships_files_data_schema import TalentRelationshipsFilesDataSchema as TalentRelationshipsFilesDataSchema
from smartytalent_client.models.talent_relationships_files_schema import TalentRelationshipsFilesSchema as TalentRelationshipsFilesSchema
from smartytalent_client.models.talent_relationships_operations_data_schema import TalentRelationshipsOperationsDataSchema as TalentRelationshipsOperationsDataSchema
from smartytalent_client.models.talent_relationships_operations_schema import TalentRelationshipsOperationsSchema as TalentRelationshipsOperationsSchema
from smartytalent_client.models.talent_relationships_schema import TalentRelationshipsSchema as TalentRelationshipsSchema
from smartytalent_client.models.talent_relationships_translations_data_schema import TalentRelationshipsTranslationsDataSchema as TalentRelationshipsTranslationsDataSchema
from smartytalent_client.models.talent_relationships_translations_schema import TalentRelationshipsTranslationsSchema as TalentRelationshipsTranslationsSchema
from smartytalent_client.models.talent_resource_schema import TalentResourceSchema as TalentResourceSchema
from smartytalent_client.models.talent_schema import TalentSchema as TalentSchema
from smartytalent_client.models.talents_schema import TalentsSchema as TalentsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema as TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_schema import TenantAttributesSchema as TenantAttributesSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema as TenantAttributesSettingsSchema
from smartytalent_client.models.tenant_attributes_settings_schema_calling import TenantAttributesSettingsSchemaCalling as TenantAttributesSettingsSchemaCalling
from smartytalent_client.models.tenant_resource_schema import TenantResourceSchema as TenantResourceSchema
from smartytalent_client.models.tenant_schema import TenantSchema as TenantSchema
from smartytalent_client.models.tenant_upload_attributes_schema import TenantUploadAttributesSchema as TenantUploadAttributesSchema
from smartytalent_client.models.tenant_upload_resource_schema import TenantUploadResourceSchema as TenantUploadResourceSchema
from smartytalent_client.models.tenant_upload_schema import TenantUploadSchema as TenantUploadSchema
from smartytalent_client.models.tenants_meta_page_schema import TenantsMetaPageSchema as TenantsMetaPageSchema
from smartytalent_client.models.tenants_meta_schema import TenantsMetaSchema as TenantsMetaSchema
from smartytalent_client.models.tenants_schema import TenantsSchema as TenantsSchema
from smartytalent_client.models.timeline_attributes_schema import TimelineAttributesSchema as TimelineAttributesSchema
from smartytalent_client.models.timeline_attributes_schema_changes_value import TimelineAttributesSchemaChangesValue as TimelineAttributesSchemaChangesValue
from smartytalent_client.models.timeline_attributes_schema_summary_value import TimelineAttributesSchemaSummaryValue as TimelineAttributesSchemaSummaryValue
from smartytalent_client.models.timeline_attributes_schema_summary_value_user import TimelineAttributesSchemaSummaryValueUser as TimelineAttributesSchemaSummaryValueUser
from smartytalent_client.models.timeline_attributes_schema_timestamps import TimelineAttributesSchemaTimestamps as TimelineAttributesSchemaTimestamps
from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema as TimelineResourceSchema
from smartytalent_client.models.timeline_schema import TimelineSchema as TimelineSchema
from smartytalent_client.models.timelines_schema import TimelinesSchema as TimelinesSchema
from smartytalent_client.models.translation_attributes_schema import TranslationAttributesSchema as TranslationAttributesSchema
from smartytalent_client.models.translation_relationships_candidate_data_schema import TranslationRelationshipsCandidateDataSchema as TranslationRelationshipsCandidateDataSchema
from smartytalent_client.models.translation_relationships_candidate_schema import TranslationRelationshipsCandidateSchema as TranslationRelationshipsCandidateSchema
from smartytalent_client.models.translation_relationships_job_data_schema import TranslationRelationshipsJobDataSchema as TranslationRelationshipsJobDataSchema
from smartytalent_client.models.translation_relationships_job_schema import TranslationRelationshipsJobSchema as TranslationRelationshipsJobSchema
from smartytalent_client.models.translation_relationships_report_data_schema import TranslationRelationshipsReportDataSchema as TranslationRelationshipsReportDataSchema
from smartytalent_client.models.translation_relationships_report_schema import TranslationRelationshipsReportSchema as TranslationRelationshipsReportSchema
from smartytalent_client.models.translation_relationships_schema import TranslationRelationshipsSchema as TranslationRelationshipsSchema
from smartytalent_client.models.translation_relationships_talent_data_schema import TranslationRelationshipsTalentDataSchema as TranslationRelationshipsTalentDataSchema
from smartytalent_client.models.translation_relationships_talent_schema import TranslationRelationshipsTalentSchema as TranslationRelationshipsTalentSchema
from smartytalent_client.models.translation_resource_schema import TranslationResourceSchema as TranslationResourceSchema
from smartytalent_client.models.translation_schema import TranslationSchema as TranslationSchema
from smartytalent_client.models.translations_schema import TranslationsSchema as TranslationsSchema
from smartytalent_client.models.update_ad_request_body import UpdateAdRequestBody as UpdateAdRequestBody
from smartytalent_client.models.update_ad_request_body_data import UpdateAdRequestBodyData as UpdateAdRequestBodyData
from smartytalent_client.models.update_apikey_request_body import UpdateApikeyRequestBody as UpdateApikeyRequestBody
from smartytalent_client.models.update_apikey_request_body_data import UpdateApikeyRequestBodyData as UpdateApikeyRequestBodyData
from smartytalent_client.models.update_assessment_request_body import UpdateAssessmentRequestBody as UpdateAssessmentRequestBody
from smartytalent_client.models.update_assessment_request_body_data import UpdateAssessmentRequestBodyData as UpdateAssessmentRequestBodyData
from smartytalent_client.models.update_browser_request_body import UpdateBrowserRequestBody as UpdateBrowserRequestBody
from smartytalent_client.models.update_browser_request_body_data import UpdateBrowserRequestBodyData as UpdateBrowserRequestBodyData
from smartytalent_client.models.update_call_request_body import UpdateCallRequestBody as UpdateCallRequestBody
from smartytalent_client.models.update_call_request_body_data import UpdateCallRequestBodyData as UpdateCallRequestBodyData
from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody as UpdateCandidateRequestBody
from smartytalent_client.models.update_candidate_request_body_data import UpdateCandidateRequestBodyData as UpdateCandidateRequestBodyData
from smartytalent_client.models.update_chat_request_body import UpdateChatRequestBody as UpdateChatRequestBody
from smartytalent_client.models.update_chat_request_body_data import UpdateChatRequestBodyData as UpdateChatRequestBodyData
from smartytalent_client.models.update_conversation_request_body import UpdateConversationRequestBody as UpdateConversationRequestBody
from smartytalent_client.models.update_conversation_request_body_data import UpdateConversationRequestBodyData as UpdateConversationRequestBodyData
from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody as UpdateEmailRequestBody
from smartytalent_client.models.update_email_request_body_data import UpdateEmailRequestBodyData as UpdateEmailRequestBodyData
from smartytalent_client.models.update_file_request_body import UpdateFileRequestBody as UpdateFileRequestBody
from smartytalent_client.models.update_file_request_body_data import UpdateFileRequestBodyData as UpdateFileRequestBodyData
from smartytalent_client.models.update_finder_request_body import UpdateFinderRequestBody as UpdateFinderRequestBody
from smartytalent_client.models.update_finder_request_body_data import UpdateFinderRequestBodyData as UpdateFinderRequestBodyData
from smartytalent_client.models.update_form_request_body import UpdateFormRequestBody as UpdateFormRequestBody
from smartytalent_client.models.update_form_request_body_data import UpdateFormRequestBodyData as UpdateFormRequestBodyData
from smartytalent_client.models.update_job_request_body import UpdateJobRequestBody as UpdateJobRequestBody
from smartytalent_client.models.update_job_request_body_data import UpdateJobRequestBodyData as UpdateJobRequestBodyData
from smartytalent_client.models.update_link_request_body import UpdateLinkRequestBody as UpdateLinkRequestBody
from smartytalent_client.models.update_link_request_body_data import UpdateLinkRequestBodyData as UpdateLinkRequestBodyData
from smartytalent_client.models.update_meeting_request_body import UpdateMeetingRequestBody as UpdateMeetingRequestBody
from smartytalent_client.models.update_meeting_request_body_data import UpdateMeetingRequestBodyData as UpdateMeetingRequestBodyData
from smartytalent_client.models.update_note_request_body import UpdateNoteRequestBody as UpdateNoteRequestBody
from smartytalent_client.models.update_note_request_body_data import UpdateNoteRequestBodyData as UpdateNoteRequestBodyData
from smartytalent_client.models.update_notification_request_body import UpdateNotificationRequestBody as UpdateNotificationRequestBody
from smartytalent_client.models.update_notification_request_body_data import UpdateNotificationRequestBodyData as UpdateNotificationRequestBodyData
from smartytalent_client.models.update_notification_request_body_data_attributes import UpdateNotificationRequestBodyDataAttributes as UpdateNotificationRequestBodyDataAttributes
from smartytalent_client.models.update_operation_request_body import UpdateOperationRequestBody as UpdateOperationRequestBody
from smartytalent_client.models.update_operation_request_body_data import UpdateOperationRequestBodyData as UpdateOperationRequestBodyData
from smartytalent_client.models.update_persona_request_body import UpdatePersonaRequestBody as UpdatePersonaRequestBody
from smartytalent_client.models.update_persona_request_body_data import UpdatePersonaRequestBodyData as UpdatePersonaRequestBodyData
from smartytalent_client.models.update_report_request_body import UpdateReportRequestBody as UpdateReportRequestBody
from smartytalent_client.models.update_report_request_body_data import UpdateReportRequestBodyData as UpdateReportRequestBodyData
from smartytalent_client.models.update_role_request_body import UpdateRoleRequestBody as UpdateRoleRequestBody
from smartytalent_client.models.update_role_request_body_data import UpdateRoleRequestBodyData as UpdateRoleRequestBodyData
from smartytalent_client.models.update_talent_request_body import UpdateTalentRequestBody as UpdateTalentRequestBody
from smartytalent_client.models.update_talent_request_body_data import UpdateTalentRequestBodyData as UpdateTalentRequestBodyData
from smartytalent_client.models.update_tenant_request_body import UpdateTenantRequestBody as UpdateTenantRequestBody
from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData as UpdateTenantRequestBodyData
from smartytalent_client.models.update_translation_request_body import UpdateTranslationRequestBody as UpdateTranslationRequestBody
from smartytalent_client.models.update_translation_request_body_data import UpdateTranslationRequestBodyData as UpdateTranslationRequestBodyData
from smartytalent_client.models.update_user_request_body import UpdateUserRequestBody as UpdateUserRequestBody
from smartytalent_client.models.update_user_request_body_data import UpdateUserRequestBodyData as UpdateUserRequestBodyData
from smartytalent_client.models.update_webhook_request_body import UpdateWebhookRequestBody as UpdateWebhookRequestBody
from smartytalent_client.models.update_webhook_request_body_data import UpdateWebhookRequestBodyData as UpdateWebhookRequestBodyData
from smartytalent_client.models.user_attributes_schema import UserAttributesSchema as UserAttributesSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema as UserHistoryEventSchema
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner as UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback as UserHistoryEventSchemaEventFeedback
from smartytalent_client.models.user_relationships_apikeys_data_schema import UserRelationshipsApikeysDataSchema as UserRelationshipsApikeysDataSchema
from smartytalent_client.models.user_relationships_apikeys_schema import UserRelationshipsApikeysSchema as UserRelationshipsApikeysSchema
from smartytalent_client.models.user_relationships_jobs_data_schema import UserRelationshipsJobsDataSchema as UserRelationshipsJobsDataSchema
from smartytalent_client.models.user_relationships_jobs_schema import UserRelationshipsJobsSchema as UserRelationshipsJobsSchema
from smartytalent_client.models.user_relationships_role_data_schema import UserRelationshipsRoleDataSchema as UserRelationshipsRoleDataSchema
from smartytalent_client.models.user_relationships_role_schema import UserRelationshipsRoleSchema as UserRelationshipsRoleSchema
from smartytalent_client.models.user_relationships_schema import UserRelationshipsSchema as UserRelationshipsSchema
from smartytalent_client.models.user_resource_schema import UserResourceSchema as UserResourceSchema
from smartytalent_client.models.user_schema import UserSchema as UserSchema
from smartytalent_client.models.user_upload_attributes_schema import UserUploadAttributesSchema as UserUploadAttributesSchema
from smartytalent_client.models.user_upload_resource_schema import UserUploadResourceSchema as UserUploadResourceSchema
from smartytalent_client.models.user_upload_schema import UserUploadSchema as UserUploadSchema
from smartytalent_client.models.users_schema import UsersSchema as UsersSchema
from smartytalent_client.models.webhook_attributes_schema import WebhookAttributesSchema as WebhookAttributesSchema
from smartytalent_client.models.webhook_resource_schema import WebhookResourceSchema as WebhookResourceSchema
from smartytalent_client.models.webhook_schema import WebhookSchema as WebhookSchema
from smartytalent_client.models.webhooks_schema import WebhooksSchema as WebhooksSchema

