# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.operations_api import OperationsApi


class TestOperationsApi(unittest.TestCase):
    """OperationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OperationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_operation(self) -> None:
        """Test case for create_operation

        Create Operation
        """
        pass

    def test_delete_operation(self) -> None:
        """Test case for delete_operation

        Delete Operation
        """
        pass

    def test_list_operations(self) -> None:
        """Test case for list_operations

        List Operations
        """
        pass

    def test_operation_options(self) -> None:
        """Test case for operation_options

        Operation Options
        """
        pass

    def test_operations_options(self) -> None:
        """Test case for operations_options

        Operations Options
        """
        pass

    def test_show_operation(self) -> None:
        """Test case for show_operation

        Show Operation
        """
        pass

    def test_update_operation(self) -> None:
        """Test case for update_operation

        Update Operation
        """
        pass


if __name__ == '__main__':
    unittest.main()
