# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ReportAttributesSchema(BaseModel):
    """
    ReportAttributesSchema
    """ # noqa: E501
    resource_id: StrictStr = Field(description="Identifier of the resource this report is associated with (job ID or tenant ID)", alias="resourceId")
    resource_type: StrictStr = Field(description="Type of the resource (tenants or jobs)", alias="resourceType")
    period: Optional[StrictStr] = Field(default=None, description="Report period frequency")
    report_content: Optional[StrictStr] = Field(default=None, description="Merged analytics and AI analysis content", alias="reportContent")
    settings: Optional[StrictStr] = Field(default=None, description="Report configuration including email recipients and period preferences")
    short_code: Optional[StrictStr] = Field(default=None, description="Optional short identifier for the report", alias="shortCode")
    source: Optional[StrictStr] = Field(default=None, description="Source of the report creation (e.g. scheduled, manual)")
    status: Optional[StrictStr] = Field(default=None, description="Current status of the report")
    ttl: Optional[StrictStr] = Field(default=None, description="Time-to-live value for automatic report expiration")
    timestamps: Optional[ResourceTimestampsSchema] = None
    __properties: ClassVar[List[str]] = ["resourceId", "resourceType", "period", "reportContent", "settings", "shortCode", "source", "status", "ttl", "timestamps"]

    @field_validator('resource_type')
    def resource_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['tenants', 'jobs']):
            raise ValueError("must be one of enum values ('tenants', 'jobs')")
        return value

    @field_validator('period')
    def period_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DAILY', 'WEEKLY', 'MONTHLY', 'QUARTERLY', 'YEARLY']):
            raise ValueError("must be one of enum values ('DAILY', 'WEEKLY', 'MONTHLY', 'QUARTERLY', 'YEARLY')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'inactive', 'pending', 'archived', 'failed']):
            raise ValueError("must be one of enum values ('active', 'inactive', 'pending', 'archived', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "resourceId": obj.get("resourceId"),
            "resourceType": obj.get("resourceType"),
            "period": obj.get("period"),
            "reportContent": obj.get("reportContent"),
            "settings": obj.get("settings"),
            "shortCode": obj.get("shortCode"),
            "source": obj.get("source"),
            "status": obj.get("status"),
            "ttl": obj.get("ttl"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None
        })
        return _obj


