# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema

class TestJobAttributesSettingsConversationSchema(unittest.TestCase):
    """JobAttributesSettingsConversationSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobAttributesSettingsConversationSchema:
        """Test JobAttributesSettingsConversationSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobAttributesSettingsConversationSchema`
        """
        model = JobAttributesSettingsConversationSchema()
        if include_optional:
            return JobAttributesSettingsConversationSchema(
                email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                    contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                        cc = [
                            ''
                            ], 
                        bcc = [
                            ''
                            ], ), 
                    delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                        initial = '', ), 
                    external_sender = True, 
                    is_sendable = True, ),
                candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                    enabled = True, 
                    questions = True, ),
                persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                    enabled = True, ),
                tone = ''
            )
        else:
            return JobAttributesSettingsConversationSchema(
        )
        """

    def testJobAttributesSettingsConversationSchema(self):
        """Test JobAttributesSettingsConversationSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
