# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody

class TestCreateAdRequestBody(unittest.TestCase):
    """CreateAdRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateAdRequestBody:
        """Test CreateAdRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAdRequestBody`
        """
        model = CreateAdRequestBody()
        if include_optional:
            return CreateAdRequestBody(
                data = smartytalent_client.models.create_ad_request_body_data.CreateAdRequestBodyData(
                    type = 'ads', 
                    attributes = smartytalent_client.models.ad_attributes_schema.AdAttributesSchema(
                        job_id = '', 
                        status = '', 
                        platforms = smartytalent_client.models.platforms.platforms(), 
                        images = [
                            smartytalent_client.models.ad_attributes_schema_images_inner.AdAttributesSchema_images_inner(
                                platform = '', 
                                s3_key = '', 
                                size = '', )
                            ], 
                        settings = smartytalent_client.models.settings.settings(), 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    relationships = smartytalent_client.models.ad_relationships_schema.AdRelationshipsSchema(
                        job = smartytalent_client.models.ad_relationships_job_schema.AdRelationshipsJobSchema(
                            data = smartytalent_client.models.ad_relationships_job_data_schema.AdRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), ), )
            )
        else:
            return CreateAdRequestBody(
                data = smartytalent_client.models.create_ad_request_body_data.CreateAdRequestBodyData(
                    type = 'ads', 
                    attributes = smartytalent_client.models.ad_attributes_schema.AdAttributesSchema(
                        job_id = '', 
                        status = '', 
                        platforms = smartytalent_client.models.platforms.platforms(), 
                        images = [
                            smartytalent_client.models.ad_attributes_schema_images_inner.AdAttributesSchema_images_inner(
                                platform = '', 
                                s3_key = '', 
                                size = '', )
                            ], 
                        settings = smartytalent_client.models.settings.settings(), 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    relationships = smartytalent_client.models.ad_relationships_schema.AdRelationshipsSchema(
                        job = smartytalent_client.models.ad_relationships_job_schema.AdRelationshipsJobSchema(
                            data = smartytalent_client.models.ad_relationships_job_data_schema.AdRelationshipsJobDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', ), ), ), ),
        )
        """

    def testCreateAdRequestBody(self):
        """Test CreateAdRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
