# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.notifications_api import NotificationsApi


class TestNotificationsApi(unittest.TestCase):
    """NotificationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_notification(self) -> None:
        """Test case for create_notification

        Create Notification
        """
        pass

    def test_delete_notification(self) -> None:
        """Test case for delete_notification

        Delete Notification
        """
        pass

    def test_get_notification(self) -> None:
        """Test case for get_notification

        Get Notification
        """
        pass

    def test_list_notifications(self) -> None:
        """Test case for list_notifications

        List Notifications
        """
        pass

    def test_notification_options(self) -> None:
        """Test case for notification_options

        Notification Options
        """
        pass

    def test_notifications_options(self) -> None:
        """Test case for notifications_options

        Notifications Options
        """
        pass

    def test_update_notification(self) -> None:
        """Test case for update_notification

        Update Notification
        """
        pass


if __name__ == '__main__':
    unittest.main()
