# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.tenants_api import TenantsApi


class TestTenantsApi(unittest.TestCase):
    """TenantsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TenantsApi()

    def tearDown(self) -> None:
        pass

    def test_create_tenant(self) -> None:
        """Test case for create_tenant

        Create Tenant
        """
        pass

    def test_create_tenant_upload(self) -> None:
        """Test case for create_tenant_upload

        Create Tenant Upload
        """
        pass

    def test_delete_tenant(self) -> None:
        """Test case for delete_tenant

        Delete Tenant
        """
        pass

    def test_list_tenants(self) -> None:
        """Test case for list_tenants

        List Tenants
        """
        pass

    def test_purchase_tenant_phone_number(self) -> None:
        """Test case for purchase_tenant_phone_number

        Purchase Phone Number
        """
        pass

    def test_release_tenant_phone_number(self) -> None:
        """Test case for release_tenant_phone_number

        Release Phone Number
        """
        pass

    def test_search_tenant_phone_numbers(self) -> None:
        """Test case for search_tenant_phone_numbers

        Search Available Phone Numbers
        """
        pass

    def test_show_tenant(self) -> None:
        """Test case for show_tenant

        Show Tenant
        """
        pass

    def test_tenant_options(self) -> None:
        """Test case for tenant_options

        Tenant Options
        """
        pass

    def test_tenant_phone_numbers_options(self) -> None:
        """Test case for tenant_phone_numbers_options

        Phone Numbers Options
        """
        pass

    def test_tenant_phone_numbers_search_options(self) -> None:
        """Test case for tenant_phone_numbers_search_options

        Phone Numbers Search Options
        """
        pass

    def test_tenant_uploads_options(self) -> None:
        """Test case for tenant_uploads_options

        Tenant Uploads Options
        """
        pass

    def test_tenants_options(self) -> None:
        """Test case for tenants_options

        Tenants Options
        """
        pass

    def test_update_tenant(self) -> None:
        """Test case for update_tenant

        Update Tenant
        """
        pass


if __name__ == '__main__':
    unittest.main()
