# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class NotificationAttributesSchema(BaseModel):
    """
    NotificationAttributesSchema
    """ # noqa: E501
    title: StrictStr = Field(description="The notification title")
    subtitle: Optional[StrictStr] = Field(default=None, description="The notification subtitle")
    category: Optional[StrictStr] = Field(default='general', description="The notification category")
    status: Optional[StrictStr] = Field(default='unread', description="Read/unread status")
    avatar_icon: Optional[StrictStr] = Field(default=None, description="Tabler icon name for the notification avatar", alias="avatarIcon")
    avatar_text: Optional[StrictStr] = Field(default=None, description="Text to display in the notification avatar", alias="avatarText")
    avatar_image: Optional[StrictStr] = Field(default=None, description="Image URL for the notification avatar", alias="avatarImage")
    avatar_color: Optional[StrictStr] = Field(default='primary', description="Color theme for the notification avatar", alias="avatarColor")
    created: Optional[datetime] = Field(default=None, description="Creation timestamp")
    modified: Optional[datetime] = Field(default=None, description="Last modified timestamp")
    __properties: ClassVar[List[str]] = ["title", "subtitle", "category", "status", "avatarIcon", "avatarText", "avatarImage", "avatarColor", "created", "modified"]

    @field_validator('category')
    def category_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['general', 'task', 'finder', 'candidate', 'file', 'assessment']):
            raise ValueError("must be one of enum values ('general', 'task', 'finder', 'candidate', 'file', 'assessment')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['read', 'unread']):
            raise ValueError("must be one of enum values ('read', 'unread')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NotificationAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NotificationAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "title": obj.get("title"),
            "subtitle": obj.get("subtitle"),
            "category": obj.get("category") if obj.get("category") is not None else 'general',
            "status": obj.get("status") if obj.get("status") is not None else 'unread',
            "avatarIcon": obj.get("avatarIcon"),
            "avatarText": obj.get("avatarText"),
            "avatarImage": obj.get("avatarImage"),
            "avatarColor": obj.get("avatarColor") if obj.get("avatarColor") is not None else 'primary',
            "created": obj.get("created"),
            "modified": obj.get("modified")
        })
        return _obj


