# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class TenantAttributesSchema(BaseModel):
    """
    TenantAttributesSchema
    """ # noqa: E501
    name: StrictStr
    username: Optional[StrictStr] = None
    email: Annotated[str, Field(min_length=5, strict=True, max_length=255)]
    status: Optional[StrictStr] = None
    short_code: Optional[StrictStr] = Field(default=None, alias="shortCode")
    timestamps: Optional[ResourceTimestampsSchema] = None
    phone: Optional[StrictStr] = None
    address: Optional[TenantAttributesAddressSchema] = None
    settings: Optional[TenantAttributesSettingsSchema] = None
    plan: Annotated[str, Field(min_length=1, strict=True, max_length=255)]
    active_languages: Optional[List[Annotated[str, Field(strict=True)]]] = Field(default=None, alias="activeLanguages")
    trial_expiry_date: Optional[datetime] = Field(default=None, alias="trialExpiryDate")
    timezone: Optional[StrictStr] = None
    logo_url: Optional[StrictStr] = Field(default=None, alias="logoUrl")
    boe_phone: Optional[StrictStr] = Field(default=None, description="Twilio phone number assigned to the Boe AI agent for this tenant", alias="boePhone")
    boe_email: Optional[StrictStr] = Field(default=None, description="Email address assigned to the Boe AI agent for this tenant", alias="boeEmail")
    __properties: ClassVar[List[str]] = ["name", "username", "email", "status", "shortCode", "timestamps", "phone", "address", "settings", "plan", "activeLanguages", "trialExpiryDate", "timezone", "logoUrl", "boePhone", "boeEmail"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TenantAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TenantAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "username": obj.get("username"),
            "email": obj.get("email"),
            "status": obj.get("status"),
            "shortCode": obj.get("shortCode"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            "phone": obj.get("phone"),
            "address": TenantAttributesAddressSchema.from_dict(obj["address"]) if obj.get("address") is not None else None,
            "settings": TenantAttributesSettingsSchema.from_dict(obj["settings"]) if obj.get("settings") is not None else None,
            "plan": obj.get("plan"),
            "activeLanguages": obj.get("activeLanguages"),
            "trialExpiryDate": obj.get("trialExpiryDate"),
            "timezone": obj.get("timezone"),
            "logoUrl": obj.get("logoUrl"),
            "boePhone": obj.get("boePhone"),
            "boeEmail": obj.get("boeEmail")
        })
        return _obj


