# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData

class TestCreateFinderRequestBodyData(unittest.TestCase):
    """CreateFinderRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateFinderRequestBodyData:
        """Test CreateFinderRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateFinderRequestBodyData`
        """
        model = CreateFinderRequestBodyData()
        if include_optional:
            return CreateFinderRequestBodyData(
                type = 'finders',
                attributes = smartytalent_client.models.finder_attributes_schema.FinderAttributesSchema(
                    name = '', 
                    type = 'talents', 
                    query = smartytalent_client.models.query.query(), 
                    results = smartytalent_client.models.results.results(), 
                    status = 'active', 
                    language_code = '', 
                    settings = smartytalent_client.models.settings.settings(), 
                    source = '', 
                    short_code = '', 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.finder_relationships_schema.FinderRelationshipsSchema(
                    jobs = smartytalent_client.models.finder_relationships_jobs_schema.FinderRelationshipsJobsSchema(
                        data = [
                            smartytalent_client.models.finder_relationships_jobs_data_schema.FinderRelationshipsJobsDataSchema(
                                type = 'jobs', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', )
                            ], ), 
                    users = smartytalent_client.models.finder_relationships_users_schema.FinderRelationshipsUsersSchema(), 
                    talents = smartytalent_client.models.finder_relationships_talents_schema.FinderRelationshipsTalentsSchema(), 
                    candidates = smartytalent_client.models.finder_relationships_candidates_schema.FinderRelationshipsCandidatesSchema(), )
            )
        else:
            return CreateFinderRequestBodyData(
                type = 'finders',
                attributes = smartytalent_client.models.finder_attributes_schema.FinderAttributesSchema(
                    name = '', 
                    type = 'talents', 
                    query = smartytalent_client.models.query.query(), 
                    results = smartytalent_client.models.results.results(), 
                    status = 'active', 
                    language_code = '', 
                    settings = smartytalent_client.models.settings.settings(), 
                    source = '', 
                    short_code = '', 
                    ttl = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testCreateFinderRequestBodyData(self):
        """Test CreateFinderRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
