# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema

class TestTimelineResourceSchema(unittest.TestCase):
    """TimelineResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TimelineResourceSchema:
        """Test TimelineResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TimelineResourceSchema`
        """
        model = TimelineResourceSchema()
        if include_optional:
            return TimelineResourceSchema(
                type = 'timelines',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.timeline_attributes_schema.TimelineAttributesSchema(
                    entity_type = 'jobs', 
                    entity_id = '', 
                    action = 'INSERT', 
                    user_id = '', 
                    changes = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_changes_value.TimelineAttributesSchema_changes_value(
                            old = null, 
                            new = null, )
                        }, 
                    summary = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_summary_value.TimelineAttributesSchema_summary_value(
                            title = '', 
                            details = '', 
                            user = smartytalent_client.models.timeline_attributes_schema_summary_value_user.TimelineAttributesSchema_summary_value_user(
                                name = '', 
                                avatar_url = '', ), )
                        }, 
                    timestamps = smartytalent_client.models.timeline_attributes_schema_timestamps.TimelineAttributesSchema_timestamps(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.relationships.relationships(),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return TimelineResourceSchema(
                type = 'timelines',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.timeline_attributes_schema.TimelineAttributesSchema(
                    entity_type = 'jobs', 
                    entity_id = '', 
                    action = 'INSERT', 
                    user_id = '', 
                    changes = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_changes_value.TimelineAttributesSchema_changes_value(
                            old = null, 
                            new = null, )
                        }, 
                    summary = {
                        'key' : smartytalent_client.models.timeline_attributes_schema_summary_value.TimelineAttributesSchema_summary_value(
                            title = '', 
                            details = '', 
                            user = smartytalent_client.models.timeline_attributes_schema_summary_value_user.TimelineAttributesSchema_summary_value_user(
                                name = '', 
                                avatar_url = '', ), )
                        }, 
                    timestamps = smartytalent_client.models.timeline_attributes_schema_timestamps.TimelineAttributesSchema_timestamps(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testTimelineResourceSchema(self):
        """Test TimelineResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
