# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.talents_api import TalentsApi


class TestTalentsApi(unittest.TestCase):
    """TalentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TalentsApi()

    def tearDown(self) -> None:
        pass

    def test_create_talent(self) -> None:
        """Test case for create_talent

        Create Talent
        """
        pass

    def test_delete_talent(self) -> None:
        """Test case for delete_talent

        Delete Talent
        """
        pass

    def test_list_talent_candidates(self) -> None:
        """Test case for list_talent_candidates

        List Talent Candidates
        """
        pass

    def test_list_talent_candidates_relationship(self) -> None:
        """Test case for list_talent_candidates_relationship

        List Talent Candidates Relationship
        """
        pass

    def test_list_talents(self) -> None:
        """Test case for list_talents

        List Talents
        """
        pass

    def test_show_talent(self) -> None:
        """Test case for show_talent

        Show Talent
        """
        pass

    def test_talent_candidates_options(self) -> None:
        """Test case for talent_candidates_options

        Talent Candidates Options
        """
        pass

    def test_talent_candidates_relationships_options(self) -> None:
        """Test case for talent_candidates_relationships_options

        Talent Candidates Relationships Options
        """
        pass

    def test_talent_options(self) -> None:
        """Test case for talent_options

        Talent Options
        """
        pass

    def test_talents_options(self) -> None:
        """Test case for talents_options

        Talents Options
        """
        pass

    def test_update_talent(self) -> None:
        """Test case for update_talent

        Update Talent
        """
        pass


if __name__ == '__main__':
    unittest.main()
