# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema

class TestTalentAttributesSchema(unittest.TestCase):
    """TalentAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TalentAttributesSchema:
        """Test TalentAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TalentAttributesSchema`
        """
        model = TalentAttributesSchema()
        if include_optional:
            return TalentAttributesSchema(
                status = 'active',
                name = '',
                email = '',
                secondary_email = '',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                work_email = '',
                phone = '',
                work_phone = '',
                profile_picture_url = '',
                availability = {
                    'key' : smartytalent_client.models.talent_availability_received_criteria_schema.TalentAvailabilityReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        received = [
                            None
                            ], )
                    },
                desired_contract_length = smartytalent_client.models.talent_attributes_desired_contract_length_schema.TalentAttributesDesiredContractLengthSchema(
                    duration = '', 
                    is_assumed = True, 
                    confidence = 'Low', 
                    flexibility = '', 
                    reasoning = '', ),
                employment_type = smartytalent_client.models.talent_attributes_employment_type_schema.TalentAttributesEmploymentTypeSchema(
                    status = '', 
                    is_assumed = True, 
                    confidence = 'Low', 
                    additional_context = '', 
                    reasoning = '', ),
                experience_and_seniority = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                break_reason = '',
                quick_insights = {
                    'key' : ''
                    },
                languages_spoken = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                social_links = [
                    smartytalent_client.models.talent_attributes_social_link_schema.TalentAttributesSocialLinkSchema(
                        platform = '', 
                        url = '', )
                    ],
                desired_employment_type = [
                    smartytalent_client.models.talent_attributes_desired_employment_type_schema.TalentAttributesDesiredEmploymentTypeSchema(
                        type = '', 
                        is_assumed = True, 
                        confidence = 'Low', 
                        reasoning = '', )
                    ],
                desired_role = [
                    smartytalent_client.models.talent_attributes_desired_role_schema.TalentAttributesDesiredRoleSchema(
                        role = '', 
                        level = '', 
                        is_assumed = True, 
                        confidence = 'Low', 
                        reasoning = '', )
                    ],
                work_preferences = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                location_preferences = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                work_authorization = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                skills_and_expertise = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                certifications = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                licenses = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                professional_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                industry_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                company_type_experience = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                job_positions = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                job_tendencies = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                education = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                projects_and_achievements = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                personality_and_soft_skills = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                hobbies_and_interests = {
                    'key' : [
                        ''
                        ]
                    },
                references = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                keywords = {
                    'key' : [
                        ''
                        ]
                    },
                performance_reviews = [
                    None
                    ],
                personality_tests = { },
                salary_expectation = {
                    'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                        name = '', 
                        description = '', 
                        received = [
                            None
                            ], )
                    },
                relocation_willingness = True,
                requires_sponsorship = True,
                career_break = True,
                is_talent_pool = True,
                ttl = '',
                alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                    is_former_employee = True, 
                    previous_tenure_months = 1.337, 
                    wants_to_return = True, ),
                referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                    is_referred = True, 
                    referral_code = '', 
                    referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                        email = '', 
                        full_name = '', ), ),
                age = '',
                gender = '',
                settings = { },
                short_code = '',
                source = ''
            )
        else:
            return TalentAttributesSchema(
                name = '',
                email = '',
        )
        """

    def testTalentAttributesSchema(self):
        """Test TalentAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
